
''' Generated by OTF2 Template Engine '''

import ctypes

from .Config import conf, StrParam
from .ErrorCodes import ErrorCode, HandleErrorCode
from .GeneralDefinitions import *
from .AttributeList import AttributeList


class EventSizeEstimator(ctypes.Structure):
    pass

def EventSizeEstimator_New():
    c_New = conf.lib.OTF2_EventSizeEstimator_New
    c_New.argtypes = []
    c_New.restype = ctypes.POINTER(EventSizeEstimator)
    # NOTE: Do not errcheck here. This function returns a value, not an error code
    return c_EventSizeEstimator_New()

def EventSizeEstimator_Delete(estimator):
    c_Delete = conf.lib.OTF2_EventSizeEstimator_Delete
    c_Delete.argtypes = [ ctypes.POINTER(EventSizeEstimator) ]
    c_Delete.restype = ErrorCode
    c_Delete.errcheck = HandleErrorCode
    c_Delete(estimator)

def EventSizeEstimator_SetNumberOfStringDefinitions(estimator, numberOfStringDefinitions):
    c_SetNumberOfStringDefinitions = conf.lib.OTF2_EventSizeEstimator_SetNumberOfStringDefinitions
    c_SetNumberOfStringDefinitions.argtypes = [ ctypes.POINTER(EventSizeEstimator), StringRef ]
    c_SetNumberOfStringDefinitions.restype = ErrorCode
    c_SetNumberOfStringDefinitions.errcheck = HandleErrorCode
    c_SetNumberOfStringDefinitions(estimator, numberOfStringDefinitions)

def EventSizeEstimator_SetNumberOfAttributeDefinitions(estimator, numberOfAttributeDefinitions):
    c_SetNumberOfAttributeDefinitions = conf.lib.OTF2_EventSizeEstimator_SetNumberOfAttributeDefinitions
    c_SetNumberOfAttributeDefinitions.argtypes = [ ctypes.POINTER(EventSizeEstimator), AttributeRef ]
    c_SetNumberOfAttributeDefinitions.restype = ErrorCode
    c_SetNumberOfAttributeDefinitions.errcheck = HandleErrorCode
    c_SetNumberOfAttributeDefinitions(estimator, numberOfAttributeDefinitions)

def EventSizeEstimator_SetNumberOfLocationDefinitions(estimator, numberOfLocationDefinitions):
    c_SetNumberOfLocationDefinitions = conf.lib.OTF2_EventSizeEstimator_SetNumberOfLocationDefinitions
    c_SetNumberOfLocationDefinitions.argtypes = [ ctypes.POINTER(EventSizeEstimator), LocationRef ]
    c_SetNumberOfLocationDefinitions.restype = ErrorCode
    c_SetNumberOfLocationDefinitions.errcheck = HandleErrorCode
    c_SetNumberOfLocationDefinitions(estimator, numberOfLocationDefinitions)

def EventSizeEstimator_SetNumberOfRegionDefinitions(estimator, numberOfRegionDefinitions):
    c_SetNumberOfRegionDefinitions = conf.lib.OTF2_EventSizeEstimator_SetNumberOfRegionDefinitions
    c_SetNumberOfRegionDefinitions.argtypes = [ ctypes.POINTER(EventSizeEstimator), RegionRef ]
    c_SetNumberOfRegionDefinitions.restype = ErrorCode
    c_SetNumberOfRegionDefinitions.errcheck = HandleErrorCode
    c_SetNumberOfRegionDefinitions(estimator, numberOfRegionDefinitions)

def EventSizeEstimator_SetNumberOfGroupDefinitions(estimator, numberOfGroupDefinitions):
    c_SetNumberOfGroupDefinitions = conf.lib.OTF2_EventSizeEstimator_SetNumberOfGroupDefinitions
    c_SetNumberOfGroupDefinitions.argtypes = [ ctypes.POINTER(EventSizeEstimator), GroupRef ]
    c_SetNumberOfGroupDefinitions.restype = ErrorCode
    c_SetNumberOfGroupDefinitions.errcheck = HandleErrorCode
    c_SetNumberOfGroupDefinitions(estimator, numberOfGroupDefinitions)

def EventSizeEstimator_SetNumberOfMetricDefinitions(estimator, numberOfMetricDefinitions):
    c_SetNumberOfMetricDefinitions = conf.lib.OTF2_EventSizeEstimator_SetNumberOfMetricDefinitions
    c_SetNumberOfMetricDefinitions.argtypes = [ ctypes.POINTER(EventSizeEstimator), MetricRef ]
    c_SetNumberOfMetricDefinitions.restype = ErrorCode
    c_SetNumberOfMetricDefinitions.errcheck = HandleErrorCode
    c_SetNumberOfMetricDefinitions(estimator, numberOfMetricDefinitions)

def EventSizeEstimator_SetNumberOfCommDefinitions(estimator, numberOfCommDefinitions):
    c_SetNumberOfCommDefinitions = conf.lib.OTF2_EventSizeEstimator_SetNumberOfCommDefinitions
    c_SetNumberOfCommDefinitions.argtypes = [ ctypes.POINTER(EventSizeEstimator), CommRef ]
    c_SetNumberOfCommDefinitions.restype = ErrorCode
    c_SetNumberOfCommDefinitions.errcheck = HandleErrorCode
    c_SetNumberOfCommDefinitions(estimator, numberOfCommDefinitions)

def EventSizeEstimator_SetNumberOfParameterDefinitions(estimator, numberOfParameterDefinitions):
    c_SetNumberOfParameterDefinitions = conf.lib.OTF2_EventSizeEstimator_SetNumberOfParameterDefinitions
    c_SetNumberOfParameterDefinitions.argtypes = [ ctypes.POINTER(EventSizeEstimator), ParameterRef ]
    c_SetNumberOfParameterDefinitions.restype = ErrorCode
    c_SetNumberOfParameterDefinitions.errcheck = HandleErrorCode
    c_SetNumberOfParameterDefinitions(estimator, numberOfParameterDefinitions)

def EventSizeEstimator_SetNumberOfRmaWinDefinitions(estimator, numberOfRmaWinDefinitions):
    c_SetNumberOfRmaWinDefinitions = conf.lib.OTF2_EventSizeEstimator_SetNumberOfRmaWinDefinitions
    c_SetNumberOfRmaWinDefinitions.argtypes = [ ctypes.POINTER(EventSizeEstimator), RmaWinRef ]
    c_SetNumberOfRmaWinDefinitions.restype = ErrorCode
    c_SetNumberOfRmaWinDefinitions.errcheck = HandleErrorCode
    c_SetNumberOfRmaWinDefinitions(estimator, numberOfRmaWinDefinitions)

def EventSizeEstimator_SetNumberOfSourceCodeLocationDefinitions(estimator, numberOfSourceCodeLocationDefinitions):
    c_SetNumberOfSourceCodeLocationDefinitions = conf.lib.OTF2_EventSizeEstimator_SetNumberOfSourceCodeLocationDefinitions
    c_SetNumberOfSourceCodeLocationDefinitions.argtypes = [ ctypes.POINTER(EventSizeEstimator), SourceCodeLocationRef ]
    c_SetNumberOfSourceCodeLocationDefinitions.restype = ErrorCode
    c_SetNumberOfSourceCodeLocationDefinitions.errcheck = HandleErrorCode
    c_SetNumberOfSourceCodeLocationDefinitions(estimator, numberOfSourceCodeLocationDefinitions)

def EventSizeEstimator_SetNumberOfCallingContextDefinitions(estimator, numberOfCallingContextDefinitions):
    c_SetNumberOfCallingContextDefinitions = conf.lib.OTF2_EventSizeEstimator_SetNumberOfCallingContextDefinitions
    c_SetNumberOfCallingContextDefinitions.argtypes = [ ctypes.POINTER(EventSizeEstimator), CallingContextRef ]
    c_SetNumberOfCallingContextDefinitions.restype = ErrorCode
    c_SetNumberOfCallingContextDefinitions.errcheck = HandleErrorCode
    c_SetNumberOfCallingContextDefinitions(estimator, numberOfCallingContextDefinitions)

def EventSizeEstimator_SetNumberOfInterruptGeneratorDefinitions(estimator, numberOfInterruptGeneratorDefinitions):
    c_SetNumberOfInterruptGeneratorDefinitions = conf.lib.OTF2_EventSizeEstimator_SetNumberOfInterruptGeneratorDefinitions
    c_SetNumberOfInterruptGeneratorDefinitions.argtypes = [ ctypes.POINTER(EventSizeEstimator), InterruptGeneratorRef ]
    c_SetNumberOfInterruptGeneratorDefinitions.restype = ErrorCode
    c_SetNumberOfInterruptGeneratorDefinitions.errcheck = HandleErrorCode
    c_SetNumberOfInterruptGeneratorDefinitions(estimator, numberOfInterruptGeneratorDefinitions)

def EventSizeEstimator_SetNumberOfIoFileDefinitions(estimator, numberOfIoFileDefinitions):
    c_SetNumberOfIoFileDefinitions = conf.lib.OTF2_EventSizeEstimator_SetNumberOfIoFileDefinitions
    c_SetNumberOfIoFileDefinitions.argtypes = [ ctypes.POINTER(EventSizeEstimator), IoFileRef ]
    c_SetNumberOfIoFileDefinitions.restype = ErrorCode
    c_SetNumberOfIoFileDefinitions.errcheck = HandleErrorCode
    c_SetNumberOfIoFileDefinitions(estimator, numberOfIoFileDefinitions)

def EventSizeEstimator_SetNumberOfIoHandleDefinitions(estimator, numberOfIoHandleDefinitions):
    c_SetNumberOfIoHandleDefinitions = conf.lib.OTF2_EventSizeEstimator_SetNumberOfIoHandleDefinitions
    c_SetNumberOfIoHandleDefinitions.argtypes = [ ctypes.POINTER(EventSizeEstimator), IoHandleRef ]
    c_SetNumberOfIoHandleDefinitions.restype = ErrorCode
    c_SetNumberOfIoHandleDefinitions.errcheck = HandleErrorCode
    c_SetNumberOfIoHandleDefinitions(estimator, numberOfIoHandleDefinitions)

def EventSizeEstimator_SetNumberOfLocationGroupDefinitions(estimator, numberOfLocationGroupDefinitions):
    c_SetNumberOfLocationGroupDefinitions = conf.lib.OTF2_EventSizeEstimator_SetNumberOfLocationGroupDefinitions
    c_SetNumberOfLocationGroupDefinitions.argtypes = [ ctypes.POINTER(EventSizeEstimator), LocationGroupRef ]
    c_SetNumberOfLocationGroupDefinitions.restype = ErrorCode
    c_SetNumberOfLocationGroupDefinitions.errcheck = HandleErrorCode
    c_SetNumberOfLocationGroupDefinitions(estimator, numberOfLocationGroupDefinitions)

def EventSizeEstimator_GetDefChunkSize(estimator):
    c_GetDefChunkSize = conf.lib.OTF2_EventSizeEstimator_GetDefChunkSize
    c_GetDefChunkSize.argtypes = [ ctypes.POINTER(EventSizeEstimator) ]
    c_GetDefChunkSize.restype = ctypes.c_size_t
    return c_GetDefChunkSize(estimator)

def EventSizeEstimator_GetSizeOfTimestamp(estimator):
    c_GetSizeOfTimestamp = conf.lib.OTF2_EventSizeEstimator_GetSizeOfTimestamp
    c_GetSizeOfTimestamp.argtypes = [ ctypes.POINTER(EventSizeEstimator) ]
    c_GetSizeOfTimestamp.restype = ctypes.c_size_t
    return c_EventSizeEstimator_GetSizeOfTimestamp(estimator)

def EventSizeEstimator_GetSizeOfAttributeList(estimator, attributeList):
    c_GetSizeOfAttributeList = conf.lib.OTF2_EventSizeEstimator_GetSizeOfAttributeList
    c_GetSizeOfAttributeList.argtypes = [ ctypes.POINTER(EventSizeEstimator), ctypes.POINTER(AttributeList) ]
    c_GetSizeOfAttributeList.restype = ctypes.c_size_t
    return c_GetSizeOfAttributeList(estimator, attributeList)

def EventSizeEstimator_GetSizeOfBufferFlushEvent(estimator):
    c_GetSizeOfBufferFlushEvent = conf.lib.OTF2_EventSizeEstimator_GetSizeOfBufferFlushEvent
    c_GetSizeOfBufferFlushEvent.argtypes = [ ctypes.POINTER(EventSizeEstimator) ]
    c_GetSizeOfBufferFlushEvent.restype = ctypes.c_size_t
    return c_EventSizeEstimator_GetSizeOfBufferFlushEvent(estimator)

def EventSizeEstimator_GetSizeOfMeasurementOnOffEvent(estimator):
    c_GetSizeOfMeasurementOnOffEvent = conf.lib.OTF2_EventSizeEstimator_GetSizeOfMeasurementOnOffEvent
    c_GetSizeOfMeasurementOnOffEvent.argtypes = [ ctypes.POINTER(EventSizeEstimator) ]
    c_GetSizeOfMeasurementOnOffEvent.restype = ctypes.c_size_t
    return c_EventSizeEstimator_GetSizeOfMeasurementOnOffEvent(estimator)

def EventSizeEstimator_GetSizeOfEnterEvent(estimator):
    c_GetSizeOfEnterEvent = conf.lib.OTF2_EventSizeEstimator_GetSizeOfEnterEvent
    c_GetSizeOfEnterEvent.argtypes = [ ctypes.POINTER(EventSizeEstimator) ]
    c_GetSizeOfEnterEvent.restype = ctypes.c_size_t
    return c_EventSizeEstimator_GetSizeOfEnterEvent(estimator)

def EventSizeEstimator_GetSizeOfLeaveEvent(estimator):
    c_GetSizeOfLeaveEvent = conf.lib.OTF2_EventSizeEstimator_GetSizeOfLeaveEvent
    c_GetSizeOfLeaveEvent.argtypes = [ ctypes.POINTER(EventSizeEstimator) ]
    c_GetSizeOfLeaveEvent.restype = ctypes.c_size_t
    return c_EventSizeEstimator_GetSizeOfLeaveEvent(estimator)

def EventSizeEstimator_GetSizeOfMpiSendEvent(estimator):
    c_GetSizeOfMpiSendEvent = conf.lib.OTF2_EventSizeEstimator_GetSizeOfMpiSendEvent
    c_GetSizeOfMpiSendEvent.argtypes = [ ctypes.POINTER(EventSizeEstimator) ]
    c_GetSizeOfMpiSendEvent.restype = ctypes.c_size_t
    return c_EventSizeEstimator_GetSizeOfMpiSendEvent(estimator)

def EventSizeEstimator_GetSizeOfMpiIsendEvent(estimator):
    c_GetSizeOfMpiIsendEvent = conf.lib.OTF2_EventSizeEstimator_GetSizeOfMpiIsendEvent
    c_GetSizeOfMpiIsendEvent.argtypes = [ ctypes.POINTER(EventSizeEstimator) ]
    c_GetSizeOfMpiIsendEvent.restype = ctypes.c_size_t
    return c_EventSizeEstimator_GetSizeOfMpiIsendEvent(estimator)

def EventSizeEstimator_GetSizeOfMpiIsendCompleteEvent(estimator):
    c_GetSizeOfMpiIsendCompleteEvent = conf.lib.OTF2_EventSizeEstimator_GetSizeOfMpiIsendCompleteEvent
    c_GetSizeOfMpiIsendCompleteEvent.argtypes = [ ctypes.POINTER(EventSizeEstimator) ]
    c_GetSizeOfMpiIsendCompleteEvent.restype = ctypes.c_size_t
    return c_EventSizeEstimator_GetSizeOfMpiIsendCompleteEvent(estimator)

def EventSizeEstimator_GetSizeOfMpiIrecvRequestEvent(estimator):
    c_GetSizeOfMpiIrecvRequestEvent = conf.lib.OTF2_EventSizeEstimator_GetSizeOfMpiIrecvRequestEvent
    c_GetSizeOfMpiIrecvRequestEvent.argtypes = [ ctypes.POINTER(EventSizeEstimator) ]
    c_GetSizeOfMpiIrecvRequestEvent.restype = ctypes.c_size_t
    return c_EventSizeEstimator_GetSizeOfMpiIrecvRequestEvent(estimator)

def EventSizeEstimator_GetSizeOfMpiRecvEvent(estimator):
    c_GetSizeOfMpiRecvEvent = conf.lib.OTF2_EventSizeEstimator_GetSizeOfMpiRecvEvent
    c_GetSizeOfMpiRecvEvent.argtypes = [ ctypes.POINTER(EventSizeEstimator) ]
    c_GetSizeOfMpiRecvEvent.restype = ctypes.c_size_t
    return c_EventSizeEstimator_GetSizeOfMpiRecvEvent(estimator)

def EventSizeEstimator_GetSizeOfMpiIrecvEvent(estimator):
    c_GetSizeOfMpiIrecvEvent = conf.lib.OTF2_EventSizeEstimator_GetSizeOfMpiIrecvEvent
    c_GetSizeOfMpiIrecvEvent.argtypes = [ ctypes.POINTER(EventSizeEstimator) ]
    c_GetSizeOfMpiIrecvEvent.restype = ctypes.c_size_t
    return c_EventSizeEstimator_GetSizeOfMpiIrecvEvent(estimator)

def EventSizeEstimator_GetSizeOfMpiRequestTestEvent(estimator):
    c_GetSizeOfMpiRequestTestEvent = conf.lib.OTF2_EventSizeEstimator_GetSizeOfMpiRequestTestEvent
    c_GetSizeOfMpiRequestTestEvent.argtypes = [ ctypes.POINTER(EventSizeEstimator) ]
    c_GetSizeOfMpiRequestTestEvent.restype = ctypes.c_size_t
    return c_EventSizeEstimator_GetSizeOfMpiRequestTestEvent(estimator)

def EventSizeEstimator_GetSizeOfMpiRequestCancelledEvent(estimator):
    c_GetSizeOfMpiRequestCancelledEvent = conf.lib.OTF2_EventSizeEstimator_GetSizeOfMpiRequestCancelledEvent
    c_GetSizeOfMpiRequestCancelledEvent.argtypes = [ ctypes.POINTER(EventSizeEstimator) ]
    c_GetSizeOfMpiRequestCancelledEvent.restype = ctypes.c_size_t
    return c_EventSizeEstimator_GetSizeOfMpiRequestCancelledEvent(estimator)

def EventSizeEstimator_GetSizeOfMpiCollectiveBeginEvent(estimator):
    c_GetSizeOfMpiCollectiveBeginEvent = conf.lib.OTF2_EventSizeEstimator_GetSizeOfMpiCollectiveBeginEvent
    c_GetSizeOfMpiCollectiveBeginEvent.argtypes = [ ctypes.POINTER(EventSizeEstimator) ]
    c_GetSizeOfMpiCollectiveBeginEvent.restype = ctypes.c_size_t
    return c_EventSizeEstimator_GetSizeOfMpiCollectiveBeginEvent(estimator)

def EventSizeEstimator_GetSizeOfMpiCollectiveEndEvent(estimator):
    c_GetSizeOfMpiCollectiveEndEvent = conf.lib.OTF2_EventSizeEstimator_GetSizeOfMpiCollectiveEndEvent
    c_GetSizeOfMpiCollectiveEndEvent.argtypes = [ ctypes.POINTER(EventSizeEstimator) ]
    c_GetSizeOfMpiCollectiveEndEvent.restype = ctypes.c_size_t
    return c_EventSizeEstimator_GetSizeOfMpiCollectiveEndEvent(estimator)

def EventSizeEstimator_GetSizeOfOmpForkEvent(estimator):
    c_GetSizeOfOmpForkEvent = conf.lib.OTF2_EventSizeEstimator_GetSizeOfOmpForkEvent
    c_GetSizeOfOmpForkEvent.argtypes = [ ctypes.POINTER(EventSizeEstimator) ]
    c_GetSizeOfOmpForkEvent.restype = ctypes.c_size_t
    return c_EventSizeEstimator_GetSizeOfOmpForkEvent(estimator)

def EventSizeEstimator_GetSizeOfOmpJoinEvent(estimator):
    c_GetSizeOfOmpJoinEvent = conf.lib.OTF2_EventSizeEstimator_GetSizeOfOmpJoinEvent
    c_GetSizeOfOmpJoinEvent.argtypes = [ ctypes.POINTER(EventSizeEstimator) ]
    c_GetSizeOfOmpJoinEvent.restype = ctypes.c_size_t
    return c_EventSizeEstimator_GetSizeOfOmpJoinEvent(estimator)

def EventSizeEstimator_GetSizeOfOmpAcquireLockEvent(estimator):
    c_GetSizeOfOmpAcquireLockEvent = conf.lib.OTF2_EventSizeEstimator_GetSizeOfOmpAcquireLockEvent
    c_GetSizeOfOmpAcquireLockEvent.argtypes = [ ctypes.POINTER(EventSizeEstimator) ]
    c_GetSizeOfOmpAcquireLockEvent.restype = ctypes.c_size_t
    return c_EventSizeEstimator_GetSizeOfOmpAcquireLockEvent(estimator)

def EventSizeEstimator_GetSizeOfOmpReleaseLockEvent(estimator):
    c_GetSizeOfOmpReleaseLockEvent = conf.lib.OTF2_EventSizeEstimator_GetSizeOfOmpReleaseLockEvent
    c_GetSizeOfOmpReleaseLockEvent.argtypes = [ ctypes.POINTER(EventSizeEstimator) ]
    c_GetSizeOfOmpReleaseLockEvent.restype = ctypes.c_size_t
    return c_EventSizeEstimator_GetSizeOfOmpReleaseLockEvent(estimator)

def EventSizeEstimator_GetSizeOfOmpTaskCreateEvent(estimator):
    c_GetSizeOfOmpTaskCreateEvent = conf.lib.OTF2_EventSizeEstimator_GetSizeOfOmpTaskCreateEvent
    c_GetSizeOfOmpTaskCreateEvent.argtypes = [ ctypes.POINTER(EventSizeEstimator) ]
    c_GetSizeOfOmpTaskCreateEvent.restype = ctypes.c_size_t
    return c_EventSizeEstimator_GetSizeOfOmpTaskCreateEvent(estimator)

def EventSizeEstimator_GetSizeOfOmpTaskSwitchEvent(estimator):
    c_GetSizeOfOmpTaskSwitchEvent = conf.lib.OTF2_EventSizeEstimator_GetSizeOfOmpTaskSwitchEvent
    c_GetSizeOfOmpTaskSwitchEvent.argtypes = [ ctypes.POINTER(EventSizeEstimator) ]
    c_GetSizeOfOmpTaskSwitchEvent.restype = ctypes.c_size_t
    return c_EventSizeEstimator_GetSizeOfOmpTaskSwitchEvent(estimator)

def EventSizeEstimator_GetSizeOfOmpTaskCompleteEvent(estimator):
    c_GetSizeOfOmpTaskCompleteEvent = conf.lib.OTF2_EventSizeEstimator_GetSizeOfOmpTaskCompleteEvent
    c_GetSizeOfOmpTaskCompleteEvent.argtypes = [ ctypes.POINTER(EventSizeEstimator) ]
    c_GetSizeOfOmpTaskCompleteEvent.restype = ctypes.c_size_t
    return c_EventSizeEstimator_GetSizeOfOmpTaskCompleteEvent(estimator)

def EventSizeEstimator_GetSizeOfMetricEvent(estimator, numberOfMetrics):
    c_GetSizeOfMetricEvent = conf.lib.OTF2_EventSizeEstimator_GetSizeOfMetricEvent
    c_GetSizeOfMetricEvent.argtypes = [ ctypes.POINTER(EventSizeEstimator), ctypes.c_uint8 ]
    c_GetSizeOfMetricEvent.restype = ctypes.c_size_t
    return c_EventSizeEstimator_GetSizeOfMetricEvent(estimator, numberOfMetrics)

def EventSizeEstimator_GetSizeOfParameterStringEvent(estimator):
    c_GetSizeOfParameterStringEvent = conf.lib.OTF2_EventSizeEstimator_GetSizeOfParameterStringEvent
    c_GetSizeOfParameterStringEvent.argtypes = [ ctypes.POINTER(EventSizeEstimator) ]
    c_GetSizeOfParameterStringEvent.restype = ctypes.c_size_t
    return c_EventSizeEstimator_GetSizeOfParameterStringEvent(estimator)

def EventSizeEstimator_GetSizeOfParameterIntEvent(estimator):
    c_GetSizeOfParameterIntEvent = conf.lib.OTF2_EventSizeEstimator_GetSizeOfParameterIntEvent
    c_GetSizeOfParameterIntEvent.argtypes = [ ctypes.POINTER(EventSizeEstimator) ]
    c_GetSizeOfParameterIntEvent.restype = ctypes.c_size_t
    return c_EventSizeEstimator_GetSizeOfParameterIntEvent(estimator)

def EventSizeEstimator_GetSizeOfParameterUnsignedIntEvent(estimator):
    c_GetSizeOfParameterUnsignedIntEvent = conf.lib.OTF2_EventSizeEstimator_GetSizeOfParameterUnsignedIntEvent
    c_GetSizeOfParameterUnsignedIntEvent.argtypes = [ ctypes.POINTER(EventSizeEstimator) ]
    c_GetSizeOfParameterUnsignedIntEvent.restype = ctypes.c_size_t
    return c_EventSizeEstimator_GetSizeOfParameterUnsignedIntEvent(estimator)

def EventSizeEstimator_GetSizeOfRmaWinCreateEvent(estimator):
    c_GetSizeOfRmaWinCreateEvent = conf.lib.OTF2_EventSizeEstimator_GetSizeOfRmaWinCreateEvent
    c_GetSizeOfRmaWinCreateEvent.argtypes = [ ctypes.POINTER(EventSizeEstimator) ]
    c_GetSizeOfRmaWinCreateEvent.restype = ctypes.c_size_t
    return c_EventSizeEstimator_GetSizeOfRmaWinCreateEvent(estimator)

def EventSizeEstimator_GetSizeOfRmaWinDestroyEvent(estimator):
    c_GetSizeOfRmaWinDestroyEvent = conf.lib.OTF2_EventSizeEstimator_GetSizeOfRmaWinDestroyEvent
    c_GetSizeOfRmaWinDestroyEvent.argtypes = [ ctypes.POINTER(EventSizeEstimator) ]
    c_GetSizeOfRmaWinDestroyEvent.restype = ctypes.c_size_t
    return c_EventSizeEstimator_GetSizeOfRmaWinDestroyEvent(estimator)

def EventSizeEstimator_GetSizeOfRmaCollectiveBeginEvent(estimator):
    c_GetSizeOfRmaCollectiveBeginEvent = conf.lib.OTF2_EventSizeEstimator_GetSizeOfRmaCollectiveBeginEvent
    c_GetSizeOfRmaCollectiveBeginEvent.argtypes = [ ctypes.POINTER(EventSizeEstimator) ]
    c_GetSizeOfRmaCollectiveBeginEvent.restype = ctypes.c_size_t
    return c_EventSizeEstimator_GetSizeOfRmaCollectiveBeginEvent(estimator)

def EventSizeEstimator_GetSizeOfRmaCollectiveEndEvent(estimator):
    c_GetSizeOfRmaCollectiveEndEvent = conf.lib.OTF2_EventSizeEstimator_GetSizeOfRmaCollectiveEndEvent
    c_GetSizeOfRmaCollectiveEndEvent.argtypes = [ ctypes.POINTER(EventSizeEstimator) ]
    c_GetSizeOfRmaCollectiveEndEvent.restype = ctypes.c_size_t
    return c_EventSizeEstimator_GetSizeOfRmaCollectiveEndEvent(estimator)

def EventSizeEstimator_GetSizeOfRmaGroupSyncEvent(estimator):
    c_GetSizeOfRmaGroupSyncEvent = conf.lib.OTF2_EventSizeEstimator_GetSizeOfRmaGroupSyncEvent
    c_GetSizeOfRmaGroupSyncEvent.argtypes = [ ctypes.POINTER(EventSizeEstimator) ]
    c_GetSizeOfRmaGroupSyncEvent.restype = ctypes.c_size_t
    return c_EventSizeEstimator_GetSizeOfRmaGroupSyncEvent(estimator)

def EventSizeEstimator_GetSizeOfRmaRequestLockEvent(estimator):
    c_GetSizeOfRmaRequestLockEvent = conf.lib.OTF2_EventSizeEstimator_GetSizeOfRmaRequestLockEvent
    c_GetSizeOfRmaRequestLockEvent.argtypes = [ ctypes.POINTER(EventSizeEstimator) ]
    c_GetSizeOfRmaRequestLockEvent.restype = ctypes.c_size_t
    return c_EventSizeEstimator_GetSizeOfRmaRequestLockEvent(estimator)

def EventSizeEstimator_GetSizeOfRmaAcquireLockEvent(estimator):
    c_GetSizeOfRmaAcquireLockEvent = conf.lib.OTF2_EventSizeEstimator_GetSizeOfRmaAcquireLockEvent
    c_GetSizeOfRmaAcquireLockEvent.argtypes = [ ctypes.POINTER(EventSizeEstimator) ]
    c_GetSizeOfRmaAcquireLockEvent.restype = ctypes.c_size_t
    return c_EventSizeEstimator_GetSizeOfRmaAcquireLockEvent(estimator)

def EventSizeEstimator_GetSizeOfRmaTryLockEvent(estimator):
    c_GetSizeOfRmaTryLockEvent = conf.lib.OTF2_EventSizeEstimator_GetSizeOfRmaTryLockEvent
    c_GetSizeOfRmaTryLockEvent.argtypes = [ ctypes.POINTER(EventSizeEstimator) ]
    c_GetSizeOfRmaTryLockEvent.restype = ctypes.c_size_t
    return c_EventSizeEstimator_GetSizeOfRmaTryLockEvent(estimator)

def EventSizeEstimator_GetSizeOfRmaReleaseLockEvent(estimator):
    c_GetSizeOfRmaReleaseLockEvent = conf.lib.OTF2_EventSizeEstimator_GetSizeOfRmaReleaseLockEvent
    c_GetSizeOfRmaReleaseLockEvent.argtypes = [ ctypes.POINTER(EventSizeEstimator) ]
    c_GetSizeOfRmaReleaseLockEvent.restype = ctypes.c_size_t
    return c_EventSizeEstimator_GetSizeOfRmaReleaseLockEvent(estimator)

def EventSizeEstimator_GetSizeOfRmaSyncEvent(estimator):
    c_GetSizeOfRmaSyncEvent = conf.lib.OTF2_EventSizeEstimator_GetSizeOfRmaSyncEvent
    c_GetSizeOfRmaSyncEvent.argtypes = [ ctypes.POINTER(EventSizeEstimator) ]
    c_GetSizeOfRmaSyncEvent.restype = ctypes.c_size_t
    return c_EventSizeEstimator_GetSizeOfRmaSyncEvent(estimator)

def EventSizeEstimator_GetSizeOfRmaWaitChangeEvent(estimator):
    c_GetSizeOfRmaWaitChangeEvent = conf.lib.OTF2_EventSizeEstimator_GetSizeOfRmaWaitChangeEvent
    c_GetSizeOfRmaWaitChangeEvent.argtypes = [ ctypes.POINTER(EventSizeEstimator) ]
    c_GetSizeOfRmaWaitChangeEvent.restype = ctypes.c_size_t
    return c_EventSizeEstimator_GetSizeOfRmaWaitChangeEvent(estimator)

def EventSizeEstimator_GetSizeOfRmaPutEvent(estimator):
    c_GetSizeOfRmaPutEvent = conf.lib.OTF2_EventSizeEstimator_GetSizeOfRmaPutEvent
    c_GetSizeOfRmaPutEvent.argtypes = [ ctypes.POINTER(EventSizeEstimator) ]
    c_GetSizeOfRmaPutEvent.restype = ctypes.c_size_t
    return c_EventSizeEstimator_GetSizeOfRmaPutEvent(estimator)

def EventSizeEstimator_GetSizeOfRmaGetEvent(estimator):
    c_GetSizeOfRmaGetEvent = conf.lib.OTF2_EventSizeEstimator_GetSizeOfRmaGetEvent
    c_GetSizeOfRmaGetEvent.argtypes = [ ctypes.POINTER(EventSizeEstimator) ]
    c_GetSizeOfRmaGetEvent.restype = ctypes.c_size_t
    return c_EventSizeEstimator_GetSizeOfRmaGetEvent(estimator)

def EventSizeEstimator_GetSizeOfRmaAtomicEvent(estimator):
    c_GetSizeOfRmaAtomicEvent = conf.lib.OTF2_EventSizeEstimator_GetSizeOfRmaAtomicEvent
    c_GetSizeOfRmaAtomicEvent.argtypes = [ ctypes.POINTER(EventSizeEstimator) ]
    c_GetSizeOfRmaAtomicEvent.restype = ctypes.c_size_t
    return c_EventSizeEstimator_GetSizeOfRmaAtomicEvent(estimator)

def EventSizeEstimator_GetSizeOfRmaOpCompleteBlockingEvent(estimator):
    c_GetSizeOfRmaOpCompleteBlockingEvent = conf.lib.OTF2_EventSizeEstimator_GetSizeOfRmaOpCompleteBlockingEvent
    c_GetSizeOfRmaOpCompleteBlockingEvent.argtypes = [ ctypes.POINTER(EventSizeEstimator) ]
    c_GetSizeOfRmaOpCompleteBlockingEvent.restype = ctypes.c_size_t
    return c_EventSizeEstimator_GetSizeOfRmaOpCompleteBlockingEvent(estimator)

def EventSizeEstimator_GetSizeOfRmaOpCompleteNonBlockingEvent(estimator):
    c_GetSizeOfRmaOpCompleteNonBlockingEvent = conf.lib.OTF2_EventSizeEstimator_GetSizeOfRmaOpCompleteNonBlockingEvent
    c_GetSizeOfRmaOpCompleteNonBlockingEvent.argtypes = [ ctypes.POINTER(EventSizeEstimator) ]
    c_GetSizeOfRmaOpCompleteNonBlockingEvent.restype = ctypes.c_size_t
    return c_EventSizeEstimator_GetSizeOfRmaOpCompleteNonBlockingEvent(estimator)

def EventSizeEstimator_GetSizeOfRmaOpTestEvent(estimator):
    c_GetSizeOfRmaOpTestEvent = conf.lib.OTF2_EventSizeEstimator_GetSizeOfRmaOpTestEvent
    c_GetSizeOfRmaOpTestEvent.argtypes = [ ctypes.POINTER(EventSizeEstimator) ]
    c_GetSizeOfRmaOpTestEvent.restype = ctypes.c_size_t
    return c_EventSizeEstimator_GetSizeOfRmaOpTestEvent(estimator)

def EventSizeEstimator_GetSizeOfRmaOpCompleteRemoteEvent(estimator):
    c_GetSizeOfRmaOpCompleteRemoteEvent = conf.lib.OTF2_EventSizeEstimator_GetSizeOfRmaOpCompleteRemoteEvent
    c_GetSizeOfRmaOpCompleteRemoteEvent.argtypes = [ ctypes.POINTER(EventSizeEstimator) ]
    c_GetSizeOfRmaOpCompleteRemoteEvent.restype = ctypes.c_size_t
    return c_EventSizeEstimator_GetSizeOfRmaOpCompleteRemoteEvent(estimator)

def EventSizeEstimator_GetSizeOfThreadForkEvent(estimator):
    c_GetSizeOfThreadForkEvent = conf.lib.OTF2_EventSizeEstimator_GetSizeOfThreadForkEvent
    c_GetSizeOfThreadForkEvent.argtypes = [ ctypes.POINTER(EventSizeEstimator) ]
    c_GetSizeOfThreadForkEvent.restype = ctypes.c_size_t
    return c_EventSizeEstimator_GetSizeOfThreadForkEvent(estimator)

def EventSizeEstimator_GetSizeOfThreadJoinEvent(estimator):
    c_GetSizeOfThreadJoinEvent = conf.lib.OTF2_EventSizeEstimator_GetSizeOfThreadJoinEvent
    c_GetSizeOfThreadJoinEvent.argtypes = [ ctypes.POINTER(EventSizeEstimator) ]
    c_GetSizeOfThreadJoinEvent.restype = ctypes.c_size_t
    return c_EventSizeEstimator_GetSizeOfThreadJoinEvent(estimator)

def EventSizeEstimator_GetSizeOfThreadTeamBeginEvent(estimator):
    c_GetSizeOfThreadTeamBeginEvent = conf.lib.OTF2_EventSizeEstimator_GetSizeOfThreadTeamBeginEvent
    c_GetSizeOfThreadTeamBeginEvent.argtypes = [ ctypes.POINTER(EventSizeEstimator) ]
    c_GetSizeOfThreadTeamBeginEvent.restype = ctypes.c_size_t
    return c_EventSizeEstimator_GetSizeOfThreadTeamBeginEvent(estimator)

def EventSizeEstimator_GetSizeOfThreadTeamEndEvent(estimator):
    c_GetSizeOfThreadTeamEndEvent = conf.lib.OTF2_EventSizeEstimator_GetSizeOfThreadTeamEndEvent
    c_GetSizeOfThreadTeamEndEvent.argtypes = [ ctypes.POINTER(EventSizeEstimator) ]
    c_GetSizeOfThreadTeamEndEvent.restype = ctypes.c_size_t
    return c_EventSizeEstimator_GetSizeOfThreadTeamEndEvent(estimator)

def EventSizeEstimator_GetSizeOfThreadAcquireLockEvent(estimator):
    c_GetSizeOfThreadAcquireLockEvent = conf.lib.OTF2_EventSizeEstimator_GetSizeOfThreadAcquireLockEvent
    c_GetSizeOfThreadAcquireLockEvent.argtypes = [ ctypes.POINTER(EventSizeEstimator) ]
    c_GetSizeOfThreadAcquireLockEvent.restype = ctypes.c_size_t
    return c_EventSizeEstimator_GetSizeOfThreadAcquireLockEvent(estimator)

def EventSizeEstimator_GetSizeOfThreadReleaseLockEvent(estimator):
    c_GetSizeOfThreadReleaseLockEvent = conf.lib.OTF2_EventSizeEstimator_GetSizeOfThreadReleaseLockEvent
    c_GetSizeOfThreadReleaseLockEvent.argtypes = [ ctypes.POINTER(EventSizeEstimator) ]
    c_GetSizeOfThreadReleaseLockEvent.restype = ctypes.c_size_t
    return c_EventSizeEstimator_GetSizeOfThreadReleaseLockEvent(estimator)

def EventSizeEstimator_GetSizeOfThreadTaskCreateEvent(estimator):
    c_GetSizeOfThreadTaskCreateEvent = conf.lib.OTF2_EventSizeEstimator_GetSizeOfThreadTaskCreateEvent
    c_GetSizeOfThreadTaskCreateEvent.argtypes = [ ctypes.POINTER(EventSizeEstimator) ]
    c_GetSizeOfThreadTaskCreateEvent.restype = ctypes.c_size_t
    return c_EventSizeEstimator_GetSizeOfThreadTaskCreateEvent(estimator)

def EventSizeEstimator_GetSizeOfThreadTaskSwitchEvent(estimator):
    c_GetSizeOfThreadTaskSwitchEvent = conf.lib.OTF2_EventSizeEstimator_GetSizeOfThreadTaskSwitchEvent
    c_GetSizeOfThreadTaskSwitchEvent.argtypes = [ ctypes.POINTER(EventSizeEstimator) ]
    c_GetSizeOfThreadTaskSwitchEvent.restype = ctypes.c_size_t
    return c_EventSizeEstimator_GetSizeOfThreadTaskSwitchEvent(estimator)

def EventSizeEstimator_GetSizeOfThreadTaskCompleteEvent(estimator):
    c_GetSizeOfThreadTaskCompleteEvent = conf.lib.OTF2_EventSizeEstimator_GetSizeOfThreadTaskCompleteEvent
    c_GetSizeOfThreadTaskCompleteEvent.argtypes = [ ctypes.POINTER(EventSizeEstimator) ]
    c_GetSizeOfThreadTaskCompleteEvent.restype = ctypes.c_size_t
    return c_EventSizeEstimator_GetSizeOfThreadTaskCompleteEvent(estimator)

def EventSizeEstimator_GetSizeOfThreadCreateEvent(estimator):
    c_GetSizeOfThreadCreateEvent = conf.lib.OTF2_EventSizeEstimator_GetSizeOfThreadCreateEvent
    c_GetSizeOfThreadCreateEvent.argtypes = [ ctypes.POINTER(EventSizeEstimator) ]
    c_GetSizeOfThreadCreateEvent.restype = ctypes.c_size_t
    return c_EventSizeEstimator_GetSizeOfThreadCreateEvent(estimator)

def EventSizeEstimator_GetSizeOfThreadBeginEvent(estimator):
    c_GetSizeOfThreadBeginEvent = conf.lib.OTF2_EventSizeEstimator_GetSizeOfThreadBeginEvent
    c_GetSizeOfThreadBeginEvent.argtypes = [ ctypes.POINTER(EventSizeEstimator) ]
    c_GetSizeOfThreadBeginEvent.restype = ctypes.c_size_t
    return c_EventSizeEstimator_GetSizeOfThreadBeginEvent(estimator)

def EventSizeEstimator_GetSizeOfThreadWaitEvent(estimator):
    c_GetSizeOfThreadWaitEvent = conf.lib.OTF2_EventSizeEstimator_GetSizeOfThreadWaitEvent
    c_GetSizeOfThreadWaitEvent.argtypes = [ ctypes.POINTER(EventSizeEstimator) ]
    c_GetSizeOfThreadWaitEvent.restype = ctypes.c_size_t
    return c_EventSizeEstimator_GetSizeOfThreadWaitEvent(estimator)

def EventSizeEstimator_GetSizeOfThreadEndEvent(estimator):
    c_GetSizeOfThreadEndEvent = conf.lib.OTF2_EventSizeEstimator_GetSizeOfThreadEndEvent
    c_GetSizeOfThreadEndEvent.argtypes = [ ctypes.POINTER(EventSizeEstimator) ]
    c_GetSizeOfThreadEndEvent.restype = ctypes.c_size_t
    return c_EventSizeEstimator_GetSizeOfThreadEndEvent(estimator)

def EventSizeEstimator_GetSizeOfCallingContextEnterEvent(estimator):
    c_GetSizeOfCallingContextEnterEvent = conf.lib.OTF2_EventSizeEstimator_GetSizeOfCallingContextEnterEvent
    c_GetSizeOfCallingContextEnterEvent.argtypes = [ ctypes.POINTER(EventSizeEstimator) ]
    c_GetSizeOfCallingContextEnterEvent.restype = ctypes.c_size_t
    return c_EventSizeEstimator_GetSizeOfCallingContextEnterEvent(estimator)

def EventSizeEstimator_GetSizeOfCallingContextLeaveEvent(estimator):
    c_GetSizeOfCallingContextLeaveEvent = conf.lib.OTF2_EventSizeEstimator_GetSizeOfCallingContextLeaveEvent
    c_GetSizeOfCallingContextLeaveEvent.argtypes = [ ctypes.POINTER(EventSizeEstimator) ]
    c_GetSizeOfCallingContextLeaveEvent.restype = ctypes.c_size_t
    return c_EventSizeEstimator_GetSizeOfCallingContextLeaveEvent(estimator)

def EventSizeEstimator_GetSizeOfCallingContextSampleEvent(estimator):
    c_GetSizeOfCallingContextSampleEvent = conf.lib.OTF2_EventSizeEstimator_GetSizeOfCallingContextSampleEvent
    c_GetSizeOfCallingContextSampleEvent.argtypes = [ ctypes.POINTER(EventSizeEstimator) ]
    c_GetSizeOfCallingContextSampleEvent.restype = ctypes.c_size_t
    return c_EventSizeEstimator_GetSizeOfCallingContextSampleEvent(estimator)

def EventSizeEstimator_GetSizeOfIoCreateHandleEvent(estimator):
    c_GetSizeOfIoCreateHandleEvent = conf.lib.OTF2_EventSizeEstimator_GetSizeOfIoCreateHandleEvent
    c_GetSizeOfIoCreateHandleEvent.argtypes = [ ctypes.POINTER(EventSizeEstimator) ]
    c_GetSizeOfIoCreateHandleEvent.restype = ctypes.c_size_t
    return c_EventSizeEstimator_GetSizeOfIoCreateHandleEvent(estimator)

def EventSizeEstimator_GetSizeOfIoDestroyHandleEvent(estimator):
    c_GetSizeOfIoDestroyHandleEvent = conf.lib.OTF2_EventSizeEstimator_GetSizeOfIoDestroyHandleEvent
    c_GetSizeOfIoDestroyHandleEvent.argtypes = [ ctypes.POINTER(EventSizeEstimator) ]
    c_GetSizeOfIoDestroyHandleEvent.restype = ctypes.c_size_t
    return c_EventSizeEstimator_GetSizeOfIoDestroyHandleEvent(estimator)

def EventSizeEstimator_GetSizeOfIoDuplicateHandleEvent(estimator):
    c_GetSizeOfIoDuplicateHandleEvent = conf.lib.OTF2_EventSizeEstimator_GetSizeOfIoDuplicateHandleEvent
    c_GetSizeOfIoDuplicateHandleEvent.argtypes = [ ctypes.POINTER(EventSizeEstimator) ]
    c_GetSizeOfIoDuplicateHandleEvent.restype = ctypes.c_size_t
    return c_EventSizeEstimator_GetSizeOfIoDuplicateHandleEvent(estimator)

def EventSizeEstimator_GetSizeOfIoSeekEvent(estimator):
    c_GetSizeOfIoSeekEvent = conf.lib.OTF2_EventSizeEstimator_GetSizeOfIoSeekEvent
    c_GetSizeOfIoSeekEvent.argtypes = [ ctypes.POINTER(EventSizeEstimator) ]
    c_GetSizeOfIoSeekEvent.restype = ctypes.c_size_t
    return c_EventSizeEstimator_GetSizeOfIoSeekEvent(estimator)

def EventSizeEstimator_GetSizeOfIoChangeStatusFlagsEvent(estimator):
    c_GetSizeOfIoChangeStatusFlagsEvent = conf.lib.OTF2_EventSizeEstimator_GetSizeOfIoChangeStatusFlagsEvent
    c_GetSizeOfIoChangeStatusFlagsEvent.argtypes = [ ctypes.POINTER(EventSizeEstimator) ]
    c_GetSizeOfIoChangeStatusFlagsEvent.restype = ctypes.c_size_t
    return c_EventSizeEstimator_GetSizeOfIoChangeStatusFlagsEvent(estimator)

def EventSizeEstimator_GetSizeOfIoDeleteFileEvent(estimator):
    c_GetSizeOfIoDeleteFileEvent = conf.lib.OTF2_EventSizeEstimator_GetSizeOfIoDeleteFileEvent
    c_GetSizeOfIoDeleteFileEvent.argtypes = [ ctypes.POINTER(EventSizeEstimator) ]
    c_GetSizeOfIoDeleteFileEvent.restype = ctypes.c_size_t
    return c_EventSizeEstimator_GetSizeOfIoDeleteFileEvent(estimator)

def EventSizeEstimator_GetSizeOfIoOperationBeginEvent(estimator):
    c_GetSizeOfIoOperationBeginEvent = conf.lib.OTF2_EventSizeEstimator_GetSizeOfIoOperationBeginEvent
    c_GetSizeOfIoOperationBeginEvent.argtypes = [ ctypes.POINTER(EventSizeEstimator) ]
    c_GetSizeOfIoOperationBeginEvent.restype = ctypes.c_size_t
    return c_EventSizeEstimator_GetSizeOfIoOperationBeginEvent(estimator)

def EventSizeEstimator_GetSizeOfIoOperationTestEvent(estimator):
    c_GetSizeOfIoOperationTestEvent = conf.lib.OTF2_EventSizeEstimator_GetSizeOfIoOperationTestEvent
    c_GetSizeOfIoOperationTestEvent.argtypes = [ ctypes.POINTER(EventSizeEstimator) ]
    c_GetSizeOfIoOperationTestEvent.restype = ctypes.c_size_t
    return c_EventSizeEstimator_GetSizeOfIoOperationTestEvent(estimator)

def EventSizeEstimator_GetSizeOfIoOperationIssuedEvent(estimator):
    c_GetSizeOfIoOperationIssuedEvent = conf.lib.OTF2_EventSizeEstimator_GetSizeOfIoOperationIssuedEvent
    c_GetSizeOfIoOperationIssuedEvent.argtypes = [ ctypes.POINTER(EventSizeEstimator) ]
    c_GetSizeOfIoOperationIssuedEvent.restype = ctypes.c_size_t
    return c_EventSizeEstimator_GetSizeOfIoOperationIssuedEvent(estimator)

def EventSizeEstimator_GetSizeOfIoOperationCompleteEvent(estimator):
    c_GetSizeOfIoOperationCompleteEvent = conf.lib.OTF2_EventSizeEstimator_GetSizeOfIoOperationCompleteEvent
    c_GetSizeOfIoOperationCompleteEvent.argtypes = [ ctypes.POINTER(EventSizeEstimator) ]
    c_GetSizeOfIoOperationCompleteEvent.restype = ctypes.c_size_t
    return c_EventSizeEstimator_GetSizeOfIoOperationCompleteEvent(estimator)

def EventSizeEstimator_GetSizeOfIoOperationCancelledEvent(estimator):
    c_GetSizeOfIoOperationCancelledEvent = conf.lib.OTF2_EventSizeEstimator_GetSizeOfIoOperationCancelledEvent
    c_GetSizeOfIoOperationCancelledEvent.argtypes = [ ctypes.POINTER(EventSizeEstimator) ]
    c_GetSizeOfIoOperationCancelledEvent.restype = ctypes.c_size_t
    return c_EventSizeEstimator_GetSizeOfIoOperationCancelledEvent(estimator)

def EventSizeEstimator_GetSizeOfIoAcquireLockEvent(estimator):
    c_GetSizeOfIoAcquireLockEvent = conf.lib.OTF2_EventSizeEstimator_GetSizeOfIoAcquireLockEvent
    c_GetSizeOfIoAcquireLockEvent.argtypes = [ ctypes.POINTER(EventSizeEstimator) ]
    c_GetSizeOfIoAcquireLockEvent.restype = ctypes.c_size_t
    return c_EventSizeEstimator_GetSizeOfIoAcquireLockEvent(estimator)

def EventSizeEstimator_GetSizeOfIoReleaseLockEvent(estimator):
    c_GetSizeOfIoReleaseLockEvent = conf.lib.OTF2_EventSizeEstimator_GetSizeOfIoReleaseLockEvent
    c_GetSizeOfIoReleaseLockEvent.argtypes = [ ctypes.POINTER(EventSizeEstimator) ]
    c_GetSizeOfIoReleaseLockEvent.restype = ctypes.c_size_t
    return c_EventSizeEstimator_GetSizeOfIoReleaseLockEvent(estimator)

def EventSizeEstimator_GetSizeOfIoTryLockEvent(estimator):
    c_GetSizeOfIoTryLockEvent = conf.lib.OTF2_EventSizeEstimator_GetSizeOfIoTryLockEvent
    c_GetSizeOfIoTryLockEvent.argtypes = [ ctypes.POINTER(EventSizeEstimator) ]
    c_GetSizeOfIoTryLockEvent.restype = ctypes.c_size_t
    return c_EventSizeEstimator_GetSizeOfIoTryLockEvent(estimator)

def EventSizeEstimator_GetSizeOfProgramBeginEvent(estimator, numberOfArguments):
    c_GetSizeOfProgramBeginEvent = conf.lib.OTF2_EventSizeEstimator_GetSizeOfProgramBeginEvent
    c_GetSizeOfProgramBeginEvent.argtypes = [ ctypes.POINTER(EventSizeEstimator), ctypes.c_uint32 ]
    c_GetSizeOfProgramBeginEvent.restype = ctypes.c_size_t
    return c_EventSizeEstimator_GetSizeOfProgramBeginEvent(estimator, numberOfArguments)

def EventSizeEstimator_GetSizeOfProgramEndEvent(estimator):
    c_GetSizeOfProgramEndEvent = conf.lib.OTF2_EventSizeEstimator_GetSizeOfProgramEndEvent
    c_GetSizeOfProgramEndEvent.argtypes = [ ctypes.POINTER(EventSizeEstimator) ]
    c_GetSizeOfProgramEndEvent.restype = ctypes.c_size_t
    return c_EventSizeEstimator_GetSizeOfProgramEndEvent(estimator)

def EventSizeEstimator_GetSizeOfNonBlockingCollectiveRequestEvent(estimator):
    c_GetSizeOfNonBlockingCollectiveRequestEvent = conf.lib.OTF2_EventSizeEstimator_GetSizeOfNonBlockingCollectiveRequestEvent
    c_GetSizeOfNonBlockingCollectiveRequestEvent.argtypes = [ ctypes.POINTER(EventSizeEstimator) ]
    c_GetSizeOfNonBlockingCollectiveRequestEvent.restype = ctypes.c_size_t
    return c_EventSizeEstimator_GetSizeOfNonBlockingCollectiveRequestEvent(estimator)

def EventSizeEstimator_GetSizeOfNonBlockingCollectiveCompleteEvent(estimator):
    c_GetSizeOfNonBlockingCollectiveCompleteEvent = conf.lib.OTF2_EventSizeEstimator_GetSizeOfNonBlockingCollectiveCompleteEvent
    c_GetSizeOfNonBlockingCollectiveCompleteEvent.argtypes = [ ctypes.POINTER(EventSizeEstimator) ]
    c_GetSizeOfNonBlockingCollectiveCompleteEvent.restype = ctypes.c_size_t
    return c_EventSizeEstimator_GetSizeOfNonBlockingCollectiveCompleteEvent(estimator)

def EventSizeEstimator_GetSizeOfCommCreateEvent(estimator):
    c_GetSizeOfCommCreateEvent = conf.lib.OTF2_EventSizeEstimator_GetSizeOfCommCreateEvent
    c_GetSizeOfCommCreateEvent.argtypes = [ ctypes.POINTER(EventSizeEstimator) ]
    c_GetSizeOfCommCreateEvent.restype = ctypes.c_size_t
    return c_EventSizeEstimator_GetSizeOfCommCreateEvent(estimator)

def EventSizeEstimator_GetSizeOfCommDestroyEvent(estimator):
    c_GetSizeOfCommDestroyEvent = conf.lib.OTF2_EventSizeEstimator_GetSizeOfCommDestroyEvent
    c_GetSizeOfCommDestroyEvent.argtypes = [ ctypes.POINTER(EventSizeEstimator) ]
    c_GetSizeOfCommDestroyEvent.restype = ctypes.c_size_t
    return c_EventSizeEstimator_GetSizeOfCommDestroyEvent(estimator)

__all__ = [
    'EventSizeEstimator',
    'EventSizeEstimator_New',
    'EventSizeEstimator_Delete',
    'EventSizeEstimator_GetDefChunkSize',
    'EventSizeEstimator_GetSizeOfTimestamp',
    'EventSizeEstimator_GetSizeOfAttributeList',
    'EventSizeEstimator_SetNumberOfStringDefinitions',
    'EventSizeEstimator_SetNumberOfAttributeDefinitions',
    'EventSizeEstimator_SetNumberOfLocationDefinitions',
    'EventSizeEstimator_SetNumberOfRegionDefinitions',
    'EventSizeEstimator_SetNumberOfGroupDefinitions',
    'EventSizeEstimator_SetNumberOfMetricDefinitions',
    'EventSizeEstimator_SetNumberOfCommDefinitions',
    'EventSizeEstimator_SetNumberOfParameterDefinitions',
    'EventSizeEstimator_SetNumberOfRmaWinDefinitions',
    'EventSizeEstimator_SetNumberOfSourceCodeLocationDefinitions',
    'EventSizeEstimator_SetNumberOfCallingContextDefinitions',
    'EventSizeEstimator_SetNumberOfInterruptGeneratorDefinitions',
    'EventSizeEstimator_SetNumberOfIoFileDefinitions',
    'EventSizeEstimator_SetNumberOfIoHandleDefinitions',
    'EventSizeEstimator_SetNumberOfLocationGroupDefinitions',
    'EventSizeEstimator_GetSizeOfBufferFlushEvent',
    'EventSizeEstimator_GetSizeOfMeasurementOnOffEvent',
    'EventSizeEstimator_GetSizeOfEnterEvent',
    'EventSizeEstimator_GetSizeOfLeaveEvent',
    'EventSizeEstimator_GetSizeOfMpiSendEvent',
    'EventSizeEstimator_GetSizeOfMpiIsendEvent',
    'EventSizeEstimator_GetSizeOfMpiIsendCompleteEvent',
    'EventSizeEstimator_GetSizeOfMpiIrecvRequestEvent',
    'EventSizeEstimator_GetSizeOfMpiRecvEvent',
    'EventSizeEstimator_GetSizeOfMpiIrecvEvent',
    'EventSizeEstimator_GetSizeOfMpiRequestTestEvent',
    'EventSizeEstimator_GetSizeOfMpiRequestCancelledEvent',
    'EventSizeEstimator_GetSizeOfMpiCollectiveBeginEvent',
    'EventSizeEstimator_GetSizeOfMpiCollectiveEndEvent',
    'EventSizeEstimator_GetSizeOfOmpForkEvent',
    'EventSizeEstimator_GetSizeOfOmpJoinEvent',
    'EventSizeEstimator_GetSizeOfOmpAcquireLockEvent',
    'EventSizeEstimator_GetSizeOfOmpReleaseLockEvent',
    'EventSizeEstimator_GetSizeOfOmpTaskCreateEvent',
    'EventSizeEstimator_GetSizeOfOmpTaskSwitchEvent',
    'EventSizeEstimator_GetSizeOfOmpTaskCompleteEvent',
    'EventSizeEstimator_GetSizeOfMetricEvent',
    'EventSizeEstimator_GetSizeOfParameterStringEvent',
    'EventSizeEstimator_GetSizeOfParameterIntEvent',
    'EventSizeEstimator_GetSizeOfParameterUnsignedIntEvent',
    'EventSizeEstimator_GetSizeOfRmaWinCreateEvent',
    'EventSizeEstimator_GetSizeOfRmaWinDestroyEvent',
    'EventSizeEstimator_GetSizeOfRmaCollectiveBeginEvent',
    'EventSizeEstimator_GetSizeOfRmaCollectiveEndEvent',
    'EventSizeEstimator_GetSizeOfRmaGroupSyncEvent',
    'EventSizeEstimator_GetSizeOfRmaRequestLockEvent',
    'EventSizeEstimator_GetSizeOfRmaAcquireLockEvent',
    'EventSizeEstimator_GetSizeOfRmaTryLockEvent',
    'EventSizeEstimator_GetSizeOfRmaReleaseLockEvent',
    'EventSizeEstimator_GetSizeOfRmaSyncEvent',
    'EventSizeEstimator_GetSizeOfRmaWaitChangeEvent',
    'EventSizeEstimator_GetSizeOfRmaPutEvent',
    'EventSizeEstimator_GetSizeOfRmaGetEvent',
    'EventSizeEstimator_GetSizeOfRmaAtomicEvent',
    'EventSizeEstimator_GetSizeOfRmaOpCompleteBlockingEvent',
    'EventSizeEstimator_GetSizeOfRmaOpCompleteNonBlockingEvent',
    'EventSizeEstimator_GetSizeOfRmaOpTestEvent',
    'EventSizeEstimator_GetSizeOfRmaOpCompleteRemoteEvent',
    'EventSizeEstimator_GetSizeOfThreadForkEvent',
    'EventSizeEstimator_GetSizeOfThreadJoinEvent',
    'EventSizeEstimator_GetSizeOfThreadTeamBeginEvent',
    'EventSizeEstimator_GetSizeOfThreadTeamEndEvent',
    'EventSizeEstimator_GetSizeOfThreadAcquireLockEvent',
    'EventSizeEstimator_GetSizeOfThreadReleaseLockEvent',
    'EventSizeEstimator_GetSizeOfThreadTaskCreateEvent',
    'EventSizeEstimator_GetSizeOfThreadTaskSwitchEvent',
    'EventSizeEstimator_GetSizeOfThreadTaskCompleteEvent',
    'EventSizeEstimator_GetSizeOfThreadCreateEvent',
    'EventSizeEstimator_GetSizeOfThreadBeginEvent',
    'EventSizeEstimator_GetSizeOfThreadWaitEvent',
    'EventSizeEstimator_GetSizeOfThreadEndEvent',
    'EventSizeEstimator_GetSizeOfCallingContextEnterEvent',
    'EventSizeEstimator_GetSizeOfCallingContextLeaveEvent',
    'EventSizeEstimator_GetSizeOfCallingContextSampleEvent',
    'EventSizeEstimator_GetSizeOfIoCreateHandleEvent',
    'EventSizeEstimator_GetSizeOfIoDestroyHandleEvent',
    'EventSizeEstimator_GetSizeOfIoDuplicateHandleEvent',
    'EventSizeEstimator_GetSizeOfIoSeekEvent',
    'EventSizeEstimator_GetSizeOfIoChangeStatusFlagsEvent',
    'EventSizeEstimator_GetSizeOfIoDeleteFileEvent',
    'EventSizeEstimator_GetSizeOfIoOperationBeginEvent',
    'EventSizeEstimator_GetSizeOfIoOperationTestEvent',
    'EventSizeEstimator_GetSizeOfIoOperationIssuedEvent',
    'EventSizeEstimator_GetSizeOfIoOperationCompleteEvent',
    'EventSizeEstimator_GetSizeOfIoOperationCancelledEvent',
    'EventSizeEstimator_GetSizeOfIoAcquireLockEvent',
    'EventSizeEstimator_GetSizeOfIoReleaseLockEvent',
    'EventSizeEstimator_GetSizeOfIoTryLockEvent',
    'EventSizeEstimator_GetSizeOfProgramBeginEvent',
    'EventSizeEstimator_GetSizeOfProgramEndEvent',
    'EventSizeEstimator_GetSizeOfNonBlockingCollectiveRequestEvent',
    'EventSizeEstimator_GetSizeOfNonBlockingCollectiveCompleteEvent',
    'EventSizeEstimator_GetSizeOfCommCreateEvent',
    'EventSizeEstimator_GetSizeOfCommDestroyEvent',
]



#!/usr/bin/env python

import otf2
from otf2.enums import Type
import time
from tempfile import mkdtemp
import os

TIMER_GRANULARITY = 1000000


def t():
    return int(round(time.time() * TIMER_GRANULARITY))


def generate_trace(archive_name="TestArchive", num_locations = 1):
    with otf2.writer.open(archive_name, timer_resolution=TIMER_GRANULARITY) as trace:

        function = trace.definitions.region("My Function")

        parent_node = trace.definitions.system_tree_node("root node")
        system_tree_node = trace.definitions.system_tree_node("myHost", parent=parent_node)
        trace.definitions.system_tree_node_property(system_tree_node, "color", value="black")
        trace.definitions.system_tree_node_property(system_tree_node, "rack #", value=42)

        location_group = trace.definitions.location_group("Initial Process",
                                                          system_tree_parent=system_tree_node)

        attr = trace.definitions.attribute("StringTest", "A test attribute", Type.STRING)
        float_attr = trace.definitions.attribute("FloatTest", "Another test attribute",
                                                 Type.DOUBLE)

        # Get convenience metric object and write one metric event
        temperature = trace.definitions.metric("Time since last coffee", unit="min")

        # Get metric members
        temp_member = trace.definitions.metric_member("Instructions", "C", otf2.MetricType.OTHER,
                                                      otf2.MetricMode.ABSOLUTE_POINT)
        power_member = trace.definitions.metric_member("Mem", "W")

        # Add metric members to the metric class object
        mclass = trace.definitions.metric_class([temp_member, power_member])

        calling_context0 = trace.definitions.calling_context(function, parent=None)
        calling_context_ = trace.definitions.calling_context(function, parent=calling_context0)
        calling_context1 = trace.definitions.calling_context(function, parent=calling_context0)
        trace.definitions.calling_context_property(calling_context1, "instruction",
                                                   value="mov R1, R2")

        irg = trace.definitions.interrupt_generator("INSTRUCTIONS", period=1337)

        for location in range(num_locations):
            writer = trace.event_writer("Main Thread {}".format(location), group=location_group)

            # Write enter event
            writer.calling_context_enter(t(), calling_context_, unwind_distance=2, attributes={attr: "Hello World"})

            writer.metric(t(), temperature, 72.0)

            # Add metric object to the location object
            writer.metric(t(), mclass, [42.0, 12345.6])

            writer.calling_context_sample(t(), calling_context1, unwind_distance=0,
                                          interrupt_generator=irg)

            # Write leave event
            writer.calling_context_leave(t(), calling_context_, attributes={float_attr: 42.0, attr: "Wurst?"})

        return trace.definitions

if __name__ == '__main__':
    trace_dir = mkdtemp(prefix="trace_test.", dir=os.getcwd())
    os.rmdir(trace_dir)
    generate_trace(trace_dir)
    print("Created trace in {}".format(trace_dir))



# coding=UTF-8
import os
import os.path
import unittest
from shutil import rmtree
from tempfile import mkdtemp
import time

import otf2
from otf2.enums import Type



TIMER_GRANULARITY = 1000000


def t():
    return int(round(time.time() * TIMER_GRANULARITY))


class TestOTF2UserData(unittest.TestCase):

    num_locations = 4
    num_events = 200
    archive_name = "otf2_test_trace"
    locations = [x * x for x in range(num_locations)]

    def setUp(self):
        self.old_cwd = os.getcwd()
        self.tmp_dirname = mkdtemp(prefix=os.path.basename(os.path.abspath(__file__))[:-3] + '_tmp', dir=self.old_cwd)

        self.orig_trace = os.path.join(self.tmp_dirname, "orig")
        self.retrace = os.path.join(self.tmp_dirname, "retrc")

        os.mkdir(self.orig_trace)
        os.mkdir(self.retrace)

        os.chdir(self.tmp_dirname)

    def tearDown(self):
        os.chdir(self.old_cwd)
        if os.getenv('KEEP_TEST_OUTPUT', '') != '':
            print(self.tmp_dirname)
        else:
            rmtree(self.tmp_dirname)

    def generate_trace(self, archive_name):
        with otf2.writer.open(archive_name, timer_resolution=TIMER_GRANULARITY) as trace:

            self.definitions = trace.definitions

            function = trace.definitions.region(u"🔄 🐹 🌳 🔍")

            parent_node = trace.definitions.system_tree_node(u"💾 √🌳")
            system_tree_node = trace.definitions.system_tree_node(u"🖥", parent=parent_node)

            location_group = trace.definitions.location_group(u"🚗 Process",
                                                              system_tree_parent=system_tree_node)

            attr = trace.definitions.attribute(u"StringTest", u"A test attribute", Type.STRING)
            float_attr = trace.definitions.attribute(u"FloatTest", u"Another test attribute",
                                                     Type.DOUBLE)

            writer = trace.event_writer(u"💓〰️", group=location_group)
            writer2 = trace.event_writer(u"💕 〰️", group=location_group)

            function2 = trace.definitions.region(u"🙋 🌍")

            # Write enter and leave event
            writer.enter(t(), function, {attr: u"🙋 🌍"})
            writer2.enter(t(), function2)
            writer.enter(t(), function, {attr: u"🙋 🌍"})
            writer.enter(t(), function, {attr: u"🙋 🌍"})
            writer.enter(t(), function, {attr: u"🙋 🌍"})

            writer.leave(t(), function, attributes={float_attr: 42.0, attr: u"🍖?"})
            writer.leave(t(), function, attributes={float_attr: 42.0, attr: u"🍖?"})
            writer.leave(t(), function, attributes={float_attr: 42.0, attr: u"🍖?"})
            writer2.leave(t(), function2)

            writer.enter(t(), function, {attr: u"🙋 🌍"})
            writer.leave(t(), function, attributes={float_attr: 42.0, attr: u"🍖?"})

            writer.leave(t(), function, attributes={float_attr: 42.0, attr: u"🍖?"})

            # Get convenience metric object and write one metric event
            temperature = trace.definitions.metric(u"⌛️☕️", unit=u"min")
            writer.metric(t(), temperature, 72.0)

            # Get metric members
            temp_member = trace.definitions.metric_member(u"🌡", u"❄️",
                                                          otf2.MetricType.OTHER,
                                                          otf2.MetricMode.ABSOLUTE_POINT)
            power_member = trace.definitions.metric_member(u"🔋", u"🔥")
            # Add metric members to the metric class object
            mclass = trace.definitions.metric_class([temp_member, power_member])
            # Add metric object to the location object
            writer.metric(t(), mclass, [42.0, 12345.6])

    def read_trace(self, archive_name):
        with otf2.reader.open(archive_name) as trace:

            count = 0
            for location, event in trace.events:
                count += 1

            assert count == 14

            assert len(self.definitions.regions) == len(trace.definitions.regions)
            for written_region in self.definitions.regions:
                for read_region in trace.definitions.regions:
                    # there should be exactly one region
                    pass
                    # ert written_region.name == read_region.name

            assert len(self.definitions.strings) == len(trace.definitions.strings)
            for written_string in self.definitions.strings:
                written_string = written_string.name
                assert written_string in [read_string.name for read_string in
                                          trace.definitions.strings]

    def rewrite_trace(self, old_anchor_path, new_archive_path):
        with otf2.reader.open(old_anchor_path) as trace_reader:
            with otf2.writer.open(new_archive_path,
                                  definitions=trace_reader.definitions) as write_trace:
                for location, event in trace_reader.events:
                    writer = write_trace.event_writer_from_location(location)
                    writer(event)

    def test_rewrite(self):
        self.generate_trace(self.orig_trace)
        self.rewrite_trace(os.path.join(self.orig_trace, "traces.otf2"), self.retrace)
        self.read_trace(os.path.join(self.retrace, "traces.otf2"))


if __name__ == '__main__':
    unittest.main()




''' Generated by OTF2 Template Engine '''

import ctypes

from .Config import conf, StrParam
from .ErrorCodes import ErrorCode, HandleErrorCode
from .GeneralDefinitions import *
from .AttributeList import AttributeList
from .Definitions import *
from .Events import *


class EvtWriter(ctypes.Structure):
    pass

def EvtWriter_GetLocationID(writer, locationID = LocationRef()):
    c_GetLocationID = conf.lib.OTF2_EvtWriter_GetLocationID
    c_GetLocationID.argtypes = [ ctypes.POINTER(EvtWriter), ctypes.POINTER(LocationRef) ]
    c_GetLocationID.restype = ErrorCode
    c_GetLocationID.errcheck = HandleErrorCode
    c_GetLocationID(writer, ctypes.byref(locationID))
    return locationID.value

def EvtWriter_SetUserData(writer, userData):
    c_SetUserData = conf.lib.OTF2_EvtWriter_SetUserData
    c_SetUserData.argtypes = [ ctypes.POINTER(EvtWriter), ctypes.py_object ]
    c_SetUserData.restype = ErrorCode
    c_SetUserData.errcheck = HandleErrorCode
    c_SetUserData(writer, ctypes.py_object(userData))

def EvtWriter_GetUserData(writer):
    c_GetUserData = conf.lib.OTF2_EvtWriter_GetUserData
    c_GetUserData.argtypes = [ ctypes.POINTER(EvtWriter), ctypes.POINTER(ctypes.c_void_p) ]
    c_GetUserData.restype = ErrorCode
    c_GetUserData.errcheck = HandleErrorCode
    userData = ctypes.c_void_p()
    c_GetUserData(writer, ctypes.byref(userData))
    return ctypes.cast(userData, ctypes.py_object).value

def EvtWriter_SetLocationID(writer, location):
    c_SetLocationID = conf.lib.OTF2_EvtWriter_SetLocationID
    c_SetLocationID.argtypes = [ ctypes.POINTER(EvtWriter), LocationRef]
    c_SetLocationID.restype = ErrorCode
    c_SetLocationID.errcheck = HandleErrorCode
    c_SetLocationID(writer, location)

def EvtWriter_GetNumberOfEvents(writer, numberOfEvents = ctypes.c_uint64()):
    c_GetNumberOfEvents = conf.lib.OTF2_EvtWriter_GetNumberOfEvents
    c_GetNumberOfEvents.argtypes = [ ctypes.POINTER(EvtWriter), ctypes.POINTER(ctypes.c_uint64)]
    c_GetNumberOfEvents.restype = ErrorCode
    c_GetNumberOfEvents.errcheck = HandleErrorCode
    c_GetNumberOfEvents(writer, ctypes.byref(numberOfEvents))
    return numberOfEvents.value

def EvtWriter_StoreRewindPoint(writer, rewindId):
    c_StoreRewindPoint = conf.lib.OTF2_EvtWriter_StoreRewindPoint
    c_StoreRewindPoint.argtypes = [ ctypes.POINTER(EvtWriter), ctypes.c_uint32 ]
    c_StoreRewindPoint.restype = ErrorCode
    c_StoreRewindPoint.errcheck = HandleErrorCode
    c_StoreRewindPoint(writer, rewindId)

def EvtWriter_Rewind(writer, rewindId):
    c_Rewind = conf.lib.OTF2_EvtWriter_Rewind
    c_Rewind.argtypes = [ ctypes.POINTER(EvtWriter), ctypes.c_uint32 ]
    c_Rewind.restype = ErrorCode
    c_Rewind.errcheck = HandleErrorCode
    c_Rewind(writer, rewindId)

def EvtWriter_ClearRewindPoint(writer, rewindId):
    c_ClearRewindPoint = conf.lib.OTF2_EvtWriter_ClearRewindPoint
    c_ClearRewindPoint.argtypes = [ ctypes.POINTER(EvtWriter), ctypes.c_uint32 ]
    c_ClearRewindPoint.restype = ErrorCode
    c_ClearRewindPoint.errcheck = HandleErrorCode
    c_ClearRewindPoint(writer, rewindId)

def EvtWriter_BufferFlush(writer, attributeList, time, stopTime):
    c_BufferFlush = conf.lib.OTF2_EvtWriter_BufferFlush
    c_BufferFlush.argtypes = [ ctypes.POINTER(EvtWriter), ctypes.POINTER(AttributeList), TimeStamp, TimeStamp ]
    c_BufferFlush.restype = ErrorCode
    c_BufferFlush.errcheck = HandleErrorCode
    c_BufferFlush(writer, attributeList, time, stopTime)

def EvtWriter_MeasurementOnOff(writer, attributeList, time, measurementMode):
    c_MeasurementOnOff = conf.lib.OTF2_EvtWriter_MeasurementOnOff
    c_MeasurementOnOff.argtypes = [ ctypes.POINTER(EvtWriter), ctypes.POINTER(AttributeList), TimeStamp, MeasurementMode ]
    c_MeasurementOnOff.restype = ErrorCode
    c_MeasurementOnOff.errcheck = HandleErrorCode
    c_MeasurementOnOff(writer, attributeList, time, measurementMode)

def EvtWriter_Enter(writer, attributeList, time, region):
    c_Enter = conf.lib.OTF2_EvtWriter_Enter
    c_Enter.argtypes = [ ctypes.POINTER(EvtWriter), ctypes.POINTER(AttributeList), TimeStamp, RegionRef ]
    c_Enter.restype = ErrorCode
    c_Enter.errcheck = HandleErrorCode
    c_Enter(writer, attributeList, time, region)

def EvtWriter_Leave(writer, attributeList, time, region):
    c_Leave = conf.lib.OTF2_EvtWriter_Leave
    c_Leave.argtypes = [ ctypes.POINTER(EvtWriter), ctypes.POINTER(AttributeList), TimeStamp, RegionRef ]
    c_Leave.restype = ErrorCode
    c_Leave.errcheck = HandleErrorCode
    c_Leave(writer, attributeList, time, region)

def EvtWriter_MpiSend(writer, attributeList, time, receiver, communicator, msgTag, msgLength):
    c_MpiSend = conf.lib.OTF2_EvtWriter_MpiSend
    c_MpiSend.argtypes = [ ctypes.POINTER(EvtWriter), ctypes.POINTER(AttributeList), TimeStamp, ctypes.c_uint32, CommRef, ctypes.c_uint32, ctypes.c_uint64 ]
    c_MpiSend.restype = ErrorCode
    c_MpiSend.errcheck = HandleErrorCode
    c_MpiSend(writer, attributeList, time, receiver, communicator, msgTag, msgLength)

def EvtWriter_MpiIsend(writer, attributeList, time, receiver, communicator, msgTag, msgLength, requestID):
    c_MpiIsend = conf.lib.OTF2_EvtWriter_MpiIsend
    c_MpiIsend.argtypes = [ ctypes.POINTER(EvtWriter), ctypes.POINTER(AttributeList), TimeStamp, ctypes.c_uint32, CommRef, ctypes.c_uint32, ctypes.c_uint64, ctypes.c_uint64 ]
    c_MpiIsend.restype = ErrorCode
    c_MpiIsend.errcheck = HandleErrorCode
    c_MpiIsend(writer, attributeList, time, receiver, communicator, msgTag, msgLength, requestID)

def EvtWriter_MpiIsendComplete(writer, attributeList, time, requestID):
    c_MpiIsendComplete = conf.lib.OTF2_EvtWriter_MpiIsendComplete
    c_MpiIsendComplete.argtypes = [ ctypes.POINTER(EvtWriter), ctypes.POINTER(AttributeList), TimeStamp, ctypes.c_uint64 ]
    c_MpiIsendComplete.restype = ErrorCode
    c_MpiIsendComplete.errcheck = HandleErrorCode
    c_MpiIsendComplete(writer, attributeList, time, requestID)

def EvtWriter_MpiIrecvRequest(writer, attributeList, time, requestID):
    c_MpiIrecvRequest = conf.lib.OTF2_EvtWriter_MpiIrecvRequest
    c_MpiIrecvRequest.argtypes = [ ctypes.POINTER(EvtWriter), ctypes.POINTER(AttributeList), TimeStamp, ctypes.c_uint64 ]
    c_MpiIrecvRequest.restype = ErrorCode
    c_MpiIrecvRequest.errcheck = HandleErrorCode
    c_MpiIrecvRequest(writer, attributeList, time, requestID)

def EvtWriter_MpiRecv(writer, attributeList, time, sender, communicator, msgTag, msgLength):
    c_MpiRecv = conf.lib.OTF2_EvtWriter_MpiRecv
    c_MpiRecv.argtypes = [ ctypes.POINTER(EvtWriter), ctypes.POINTER(AttributeList), TimeStamp, ctypes.c_uint32, CommRef, ctypes.c_uint32, ctypes.c_uint64 ]
    c_MpiRecv.restype = ErrorCode
    c_MpiRecv.errcheck = HandleErrorCode
    c_MpiRecv(writer, attributeList, time, sender, communicator, msgTag, msgLength)

def EvtWriter_MpiIrecv(writer, attributeList, time, sender, communicator, msgTag, msgLength, requestID):
    c_MpiIrecv = conf.lib.OTF2_EvtWriter_MpiIrecv
    c_MpiIrecv.argtypes = [ ctypes.POINTER(EvtWriter), ctypes.POINTER(AttributeList), TimeStamp, ctypes.c_uint32, CommRef, ctypes.c_uint32, ctypes.c_uint64, ctypes.c_uint64 ]
    c_MpiIrecv.restype = ErrorCode
    c_MpiIrecv.errcheck = HandleErrorCode
    c_MpiIrecv(writer, attributeList, time, sender, communicator, msgTag, msgLength, requestID)

def EvtWriter_MpiRequestTest(writer, attributeList, time, requestID):
    c_MpiRequestTest = conf.lib.OTF2_EvtWriter_MpiRequestTest
    c_MpiRequestTest.argtypes = [ ctypes.POINTER(EvtWriter), ctypes.POINTER(AttributeList), TimeStamp, ctypes.c_uint64 ]
    c_MpiRequestTest.restype = ErrorCode
    c_MpiRequestTest.errcheck = HandleErrorCode
    c_MpiRequestTest(writer, attributeList, time, requestID)

def EvtWriter_MpiRequestCancelled(writer, attributeList, time, requestID):
    c_MpiRequestCancelled = conf.lib.OTF2_EvtWriter_MpiRequestCancelled
    c_MpiRequestCancelled.argtypes = [ ctypes.POINTER(EvtWriter), ctypes.POINTER(AttributeList), TimeStamp, ctypes.c_uint64 ]
    c_MpiRequestCancelled.restype = ErrorCode
    c_MpiRequestCancelled.errcheck = HandleErrorCode
    c_MpiRequestCancelled(writer, attributeList, time, requestID)

def EvtWriter_MpiCollectiveBegin(writer, attributeList, time):
    c_MpiCollectiveBegin = conf.lib.OTF2_EvtWriter_MpiCollectiveBegin
    c_MpiCollectiveBegin.argtypes = [ ctypes.POINTER(EvtWriter), ctypes.POINTER(AttributeList), TimeStamp ]
    c_MpiCollectiveBegin.restype = ErrorCode
    c_MpiCollectiveBegin.errcheck = HandleErrorCode
    c_MpiCollectiveBegin(writer, attributeList, time)

def EvtWriter_MpiCollectiveEnd(writer, attributeList, time, collectiveOp, communicator, root, sizeSent, sizeReceived):
    c_MpiCollectiveEnd = conf.lib.OTF2_EvtWriter_MpiCollectiveEnd
    c_MpiCollectiveEnd.argtypes = [ ctypes.POINTER(EvtWriter), ctypes.POINTER(AttributeList), TimeStamp, CollectiveOp, CommRef, ctypes.c_uint32, ctypes.c_uint64, ctypes.c_uint64 ]
    c_MpiCollectiveEnd.restype = ErrorCode
    c_MpiCollectiveEnd.errcheck = HandleErrorCode
    c_MpiCollectiveEnd(writer, attributeList, time, collectiveOp, communicator, root, sizeSent, sizeReceived)

def EvtWriter_OmpFork(writer, attributeList, time, numberOfRequestedThreads):
    c_OmpFork = conf.lib.OTF2_EvtWriter_OmpFork
    c_OmpFork.argtypes = [ ctypes.POINTER(EvtWriter), ctypes.POINTER(AttributeList), TimeStamp, ctypes.c_uint32 ]
    c_OmpFork.restype = ErrorCode
    c_OmpFork.errcheck = HandleErrorCode
    c_OmpFork(writer, attributeList, time, numberOfRequestedThreads)

def EvtWriter_OmpJoin(writer, attributeList, time):
    c_OmpJoin = conf.lib.OTF2_EvtWriter_OmpJoin
    c_OmpJoin.argtypes = [ ctypes.POINTER(EvtWriter), ctypes.POINTER(AttributeList), TimeStamp ]
    c_OmpJoin.restype = ErrorCode
    c_OmpJoin.errcheck = HandleErrorCode
    c_OmpJoin(writer, attributeList, time)

def EvtWriter_OmpAcquireLock(writer, attributeList, time, lockID, acquisitionOrder):
    c_OmpAcquireLock = conf.lib.OTF2_EvtWriter_OmpAcquireLock
    c_OmpAcquireLock.argtypes = [ ctypes.POINTER(EvtWriter), ctypes.POINTER(AttributeList), TimeStamp, ctypes.c_uint32, ctypes.c_uint32 ]
    c_OmpAcquireLock.restype = ErrorCode
    c_OmpAcquireLock.errcheck = HandleErrorCode
    c_OmpAcquireLock(writer, attributeList, time, lockID, acquisitionOrder)

def EvtWriter_OmpReleaseLock(writer, attributeList, time, lockID, acquisitionOrder):
    c_OmpReleaseLock = conf.lib.OTF2_EvtWriter_OmpReleaseLock
    c_OmpReleaseLock.argtypes = [ ctypes.POINTER(EvtWriter), ctypes.POINTER(AttributeList), TimeStamp, ctypes.c_uint32, ctypes.c_uint32 ]
    c_OmpReleaseLock.restype = ErrorCode
    c_OmpReleaseLock.errcheck = HandleErrorCode
    c_OmpReleaseLock(writer, attributeList, time, lockID, acquisitionOrder)

def EvtWriter_OmpTaskCreate(writer, attributeList, time, taskID):
    c_OmpTaskCreate = conf.lib.OTF2_EvtWriter_OmpTaskCreate
    c_OmpTaskCreate.argtypes = [ ctypes.POINTER(EvtWriter), ctypes.POINTER(AttributeList), TimeStamp, ctypes.c_uint64 ]
    c_OmpTaskCreate.restype = ErrorCode
    c_OmpTaskCreate.errcheck = HandleErrorCode
    c_OmpTaskCreate(writer, attributeList, time, taskID)

def EvtWriter_OmpTaskSwitch(writer, attributeList, time, taskID):
    c_OmpTaskSwitch = conf.lib.OTF2_EvtWriter_OmpTaskSwitch
    c_OmpTaskSwitch.argtypes = [ ctypes.POINTER(EvtWriter), ctypes.POINTER(AttributeList), TimeStamp, ctypes.c_uint64 ]
    c_OmpTaskSwitch.restype = ErrorCode
    c_OmpTaskSwitch.errcheck = HandleErrorCode
    c_OmpTaskSwitch(writer, attributeList, time, taskID)

def EvtWriter_OmpTaskComplete(writer, attributeList, time, taskID):
    c_OmpTaskComplete = conf.lib.OTF2_EvtWriter_OmpTaskComplete
    c_OmpTaskComplete.argtypes = [ ctypes.POINTER(EvtWriter), ctypes.POINTER(AttributeList), TimeStamp, ctypes.c_uint64 ]
    c_OmpTaskComplete.restype = ErrorCode
    c_OmpTaskComplete.errcheck = HandleErrorCode
    c_OmpTaskComplete(writer, attributeList, time, taskID)

def EvtWriter_Metric(writer, attributeList, time, metric, typeIDs, metricValues):
    numberOfMetrics = len(metricValues)
    assert(numberOfMetrics == len(typeIDs))

    TypeArrayType = Type * numberOfMetrics
    type_ids_list = TypeArrayType()
    type_ids_list[:] = typeIDs

    MetricValueArrayType = MetricValue * numberOfMetrics
    metric_values_list = MetricValueArrayType()
    metric_values_list[:] = metricValues

    c_Metric = conf.lib.OTF2_EvtWriter_Metric
    c_Metric.argtypes = [ ctypes.POINTER(EvtWriter), ctypes.POINTER(AttributeList), TimeStamp, MetricRef, ctypes.c_uint8, TypeArrayType, MetricValueArrayType ]
    c_Metric.restype = ErrorCode
    c_Metric.errcheck = HandleErrorCode
    c_Metric(writer, attributeList, time , metric, numberOfMetrics, type_ids_list, metric_values_list)

def EvtWriter_ParameterString(writer, attributeList, time, parameter, string):
    c_ParameterString = conf.lib.OTF2_EvtWriter_ParameterString
    c_ParameterString.argtypes = [ ctypes.POINTER(EvtWriter), ctypes.POINTER(AttributeList), TimeStamp, ParameterRef, StringRef ]
    c_ParameterString.restype = ErrorCode
    c_ParameterString.errcheck = HandleErrorCode
    c_ParameterString(writer, attributeList, time, parameter, string)

def EvtWriter_ParameterInt(writer, attributeList, time, parameter, value):
    c_ParameterInt = conf.lib.OTF2_EvtWriter_ParameterInt
    c_ParameterInt.argtypes = [ ctypes.POINTER(EvtWriter), ctypes.POINTER(AttributeList), TimeStamp, ParameterRef, ctypes.c_int64 ]
    c_ParameterInt.restype = ErrorCode
    c_ParameterInt.errcheck = HandleErrorCode
    c_ParameterInt(writer, attributeList, time, parameter, value)

def EvtWriter_ParameterUnsignedInt(writer, attributeList, time, parameter, value):
    c_ParameterUnsignedInt = conf.lib.OTF2_EvtWriter_ParameterUnsignedInt
    c_ParameterUnsignedInt.argtypes = [ ctypes.POINTER(EvtWriter), ctypes.POINTER(AttributeList), TimeStamp, ParameterRef, ctypes.c_uint64 ]
    c_ParameterUnsignedInt.restype = ErrorCode
    c_ParameterUnsignedInt.errcheck = HandleErrorCode
    c_ParameterUnsignedInt(writer, attributeList, time, parameter, value)

def EvtWriter_RmaWinCreate(writer, attributeList, time, win):
    c_RmaWinCreate = conf.lib.OTF2_EvtWriter_RmaWinCreate
    c_RmaWinCreate.argtypes = [ ctypes.POINTER(EvtWriter), ctypes.POINTER(AttributeList), TimeStamp, RmaWinRef ]
    c_RmaWinCreate.restype = ErrorCode
    c_RmaWinCreate.errcheck = HandleErrorCode
    c_RmaWinCreate(writer, attributeList, time, win)

def EvtWriter_RmaWinDestroy(writer, attributeList, time, win):
    c_RmaWinDestroy = conf.lib.OTF2_EvtWriter_RmaWinDestroy
    c_RmaWinDestroy.argtypes = [ ctypes.POINTER(EvtWriter), ctypes.POINTER(AttributeList), TimeStamp, RmaWinRef ]
    c_RmaWinDestroy.restype = ErrorCode
    c_RmaWinDestroy.errcheck = HandleErrorCode
    c_RmaWinDestroy(writer, attributeList, time, win)

def EvtWriter_RmaCollectiveBegin(writer, attributeList, time):
    c_RmaCollectiveBegin = conf.lib.OTF2_EvtWriter_RmaCollectiveBegin
    c_RmaCollectiveBegin.argtypes = [ ctypes.POINTER(EvtWriter), ctypes.POINTER(AttributeList), TimeStamp ]
    c_RmaCollectiveBegin.restype = ErrorCode
    c_RmaCollectiveBegin.errcheck = HandleErrorCode
    c_RmaCollectiveBegin(writer, attributeList, time)

def EvtWriter_RmaCollectiveEnd(writer, attributeList, time, collectiveOp, syncLevel, win, root, bytesSent, bytesReceived):
    c_RmaCollectiveEnd = conf.lib.OTF2_EvtWriter_RmaCollectiveEnd
    c_RmaCollectiveEnd.argtypes = [ ctypes.POINTER(EvtWriter), ctypes.POINTER(AttributeList), TimeStamp, CollectiveOp, RmaSyncLevel, RmaWinRef, ctypes.c_uint32, ctypes.c_uint64, ctypes.c_uint64 ]
    c_RmaCollectiveEnd.restype = ErrorCode
    c_RmaCollectiveEnd.errcheck = HandleErrorCode
    c_RmaCollectiveEnd(writer, attributeList, time, collectiveOp, syncLevel, win, root, bytesSent, bytesReceived)

def EvtWriter_RmaGroupSync(writer, attributeList, time, syncLevel, win, group):
    c_RmaGroupSync = conf.lib.OTF2_EvtWriter_RmaGroupSync
    c_RmaGroupSync.argtypes = [ ctypes.POINTER(EvtWriter), ctypes.POINTER(AttributeList), TimeStamp, RmaSyncLevel, RmaWinRef, GroupRef ]
    c_RmaGroupSync.restype = ErrorCode
    c_RmaGroupSync.errcheck = HandleErrorCode
    c_RmaGroupSync(writer, attributeList, time, syncLevel, win, group)

def EvtWriter_RmaRequestLock(writer, attributeList, time, win, remote, lockId, lockType):
    c_RmaRequestLock = conf.lib.OTF2_EvtWriter_RmaRequestLock
    c_RmaRequestLock.argtypes = [ ctypes.POINTER(EvtWriter), ctypes.POINTER(AttributeList), TimeStamp, RmaWinRef, ctypes.c_uint32, ctypes.c_uint64, LockType ]
    c_RmaRequestLock.restype = ErrorCode
    c_RmaRequestLock.errcheck = HandleErrorCode
    c_RmaRequestLock(writer, attributeList, time, win, remote, lockId, lockType)

def EvtWriter_RmaAcquireLock(writer, attributeList, time, win, remote, lockId, lockType):
    c_RmaAcquireLock = conf.lib.OTF2_EvtWriter_RmaAcquireLock
    c_RmaAcquireLock.argtypes = [ ctypes.POINTER(EvtWriter), ctypes.POINTER(AttributeList), TimeStamp, RmaWinRef, ctypes.c_uint32, ctypes.c_uint64, LockType ]
    c_RmaAcquireLock.restype = ErrorCode
    c_RmaAcquireLock.errcheck = HandleErrorCode
    c_RmaAcquireLock(writer, attributeList, time, win, remote, lockId, lockType)

def EvtWriter_RmaTryLock(writer, attributeList, time, win, remote, lockId, lockType):
    c_RmaTryLock = conf.lib.OTF2_EvtWriter_RmaTryLock
    c_RmaTryLock.argtypes = [ ctypes.POINTER(EvtWriter), ctypes.POINTER(AttributeList), TimeStamp, RmaWinRef, ctypes.c_uint32, ctypes.c_uint64, LockType ]
    c_RmaTryLock.restype = ErrorCode
    c_RmaTryLock.errcheck = HandleErrorCode
    c_RmaTryLock(writer, attributeList, time, win, remote, lockId, lockType)

def EvtWriter_RmaReleaseLock(writer, attributeList, time, win, remote, lockId):
    c_RmaReleaseLock = conf.lib.OTF2_EvtWriter_RmaReleaseLock
    c_RmaReleaseLock.argtypes = [ ctypes.POINTER(EvtWriter), ctypes.POINTER(AttributeList), TimeStamp, RmaWinRef, ctypes.c_uint32, ctypes.c_uint64 ]
    c_RmaReleaseLock.restype = ErrorCode
    c_RmaReleaseLock.errcheck = HandleErrorCode
    c_RmaReleaseLock(writer, attributeList, time, win, remote, lockId)

def EvtWriter_RmaSync(writer, attributeList, time, win, remote, syncType):
    c_RmaSync = conf.lib.OTF2_EvtWriter_RmaSync
    c_RmaSync.argtypes = [ ctypes.POINTER(EvtWriter), ctypes.POINTER(AttributeList), TimeStamp, RmaWinRef, ctypes.c_uint32, RmaSyncType ]
    c_RmaSync.restype = ErrorCode
    c_RmaSync.errcheck = HandleErrorCode
    c_RmaSync(writer, attributeList, time, win, remote, syncType)

def EvtWriter_RmaWaitChange(writer, attributeList, time, win):
    c_RmaWaitChange = conf.lib.OTF2_EvtWriter_RmaWaitChange
    c_RmaWaitChange.argtypes = [ ctypes.POINTER(EvtWriter), ctypes.POINTER(AttributeList), TimeStamp, RmaWinRef ]
    c_RmaWaitChange.restype = ErrorCode
    c_RmaWaitChange.errcheck = HandleErrorCode
    c_RmaWaitChange(writer, attributeList, time, win)

def EvtWriter_RmaPut(writer, attributeList, time, win, remote, bytes, matchingId):
    c_RmaPut = conf.lib.OTF2_EvtWriter_RmaPut
    c_RmaPut.argtypes = [ ctypes.POINTER(EvtWriter), ctypes.POINTER(AttributeList), TimeStamp, RmaWinRef, ctypes.c_uint32, ctypes.c_uint64, ctypes.c_uint64 ]
    c_RmaPut.restype = ErrorCode
    c_RmaPut.errcheck = HandleErrorCode
    c_RmaPut(writer, attributeList, time, win, remote, bytes, matchingId)

def EvtWriter_RmaGet(writer, attributeList, time, win, remote, bytes, matchingId):
    c_RmaGet = conf.lib.OTF2_EvtWriter_RmaGet
    c_RmaGet.argtypes = [ ctypes.POINTER(EvtWriter), ctypes.POINTER(AttributeList), TimeStamp, RmaWinRef, ctypes.c_uint32, ctypes.c_uint64, ctypes.c_uint64 ]
    c_RmaGet.restype = ErrorCode
    c_RmaGet.errcheck = HandleErrorCode
    c_RmaGet(writer, attributeList, time, win, remote, bytes, matchingId)

def EvtWriter_RmaAtomic(writer, attributeList, time, win, remote, type, bytesSent, bytesReceived, matchingId):
    c_RmaAtomic = conf.lib.OTF2_EvtWriter_RmaAtomic
    c_RmaAtomic.argtypes = [ ctypes.POINTER(EvtWriter), ctypes.POINTER(AttributeList), TimeStamp, RmaWinRef, ctypes.c_uint32, RmaAtomicType, ctypes.c_uint64, ctypes.c_uint64, ctypes.c_uint64 ]
    c_RmaAtomic.restype = ErrorCode
    c_RmaAtomic.errcheck = HandleErrorCode
    c_RmaAtomic(writer, attributeList, time, win, remote, type, bytesSent, bytesReceived, matchingId)

def EvtWriter_RmaOpCompleteBlocking(writer, attributeList, time, win, matchingId):
    c_RmaOpCompleteBlocking = conf.lib.OTF2_EvtWriter_RmaOpCompleteBlocking
    c_RmaOpCompleteBlocking.argtypes = [ ctypes.POINTER(EvtWriter), ctypes.POINTER(AttributeList), TimeStamp, RmaWinRef, ctypes.c_uint64 ]
    c_RmaOpCompleteBlocking.restype = ErrorCode
    c_RmaOpCompleteBlocking.errcheck = HandleErrorCode
    c_RmaOpCompleteBlocking(writer, attributeList, time, win, matchingId)

def EvtWriter_RmaOpCompleteNonBlocking(writer, attributeList, time, win, matchingId):
    c_RmaOpCompleteNonBlocking = conf.lib.OTF2_EvtWriter_RmaOpCompleteNonBlocking
    c_RmaOpCompleteNonBlocking.argtypes = [ ctypes.POINTER(EvtWriter), ctypes.POINTER(AttributeList), TimeStamp, RmaWinRef, ctypes.c_uint64 ]
    c_RmaOpCompleteNonBlocking.restype = ErrorCode
    c_RmaOpCompleteNonBlocking.errcheck = HandleErrorCode
    c_RmaOpCompleteNonBlocking(writer, attributeList, time, win, matchingId)

def EvtWriter_RmaOpTest(writer, attributeList, time, win, matchingId):
    c_RmaOpTest = conf.lib.OTF2_EvtWriter_RmaOpTest
    c_RmaOpTest.argtypes = [ ctypes.POINTER(EvtWriter), ctypes.POINTER(AttributeList), TimeStamp, RmaWinRef, ctypes.c_uint64 ]
    c_RmaOpTest.restype = ErrorCode
    c_RmaOpTest.errcheck = HandleErrorCode
    c_RmaOpTest(writer, attributeList, time, win, matchingId)

def EvtWriter_RmaOpCompleteRemote(writer, attributeList, time, win, matchingId):
    c_RmaOpCompleteRemote = conf.lib.OTF2_EvtWriter_RmaOpCompleteRemote
    c_RmaOpCompleteRemote.argtypes = [ ctypes.POINTER(EvtWriter), ctypes.POINTER(AttributeList), TimeStamp, RmaWinRef, ctypes.c_uint64 ]
    c_RmaOpCompleteRemote.restype = ErrorCode
    c_RmaOpCompleteRemote.errcheck = HandleErrorCode
    c_RmaOpCompleteRemote(writer, attributeList, time, win, matchingId)

def EvtWriter_ThreadFork(writer, attributeList, time, model, numberOfRequestedThreads):
    c_ThreadFork = conf.lib.OTF2_EvtWriter_ThreadFork
    c_ThreadFork.argtypes = [ ctypes.POINTER(EvtWriter), ctypes.POINTER(AttributeList), TimeStamp, Paradigm, ctypes.c_uint32 ]
    c_ThreadFork.restype = ErrorCode
    c_ThreadFork.errcheck = HandleErrorCode
    c_ThreadFork(writer, attributeList, time, model, numberOfRequestedThreads)

def EvtWriter_ThreadJoin(writer, attributeList, time, model):
    c_ThreadJoin = conf.lib.OTF2_EvtWriter_ThreadJoin
    c_ThreadJoin.argtypes = [ ctypes.POINTER(EvtWriter), ctypes.POINTER(AttributeList), TimeStamp, Paradigm ]
    c_ThreadJoin.restype = ErrorCode
    c_ThreadJoin.errcheck = HandleErrorCode
    c_ThreadJoin(writer, attributeList, time, model)

def EvtWriter_ThreadTeamBegin(writer, attributeList, time, threadTeam):
    c_ThreadTeamBegin = conf.lib.OTF2_EvtWriter_ThreadTeamBegin
    c_ThreadTeamBegin.argtypes = [ ctypes.POINTER(EvtWriter), ctypes.POINTER(AttributeList), TimeStamp, CommRef ]
    c_ThreadTeamBegin.restype = ErrorCode
    c_ThreadTeamBegin.errcheck = HandleErrorCode
    c_ThreadTeamBegin(writer, attributeList, time, threadTeam)

def EvtWriter_ThreadTeamEnd(writer, attributeList, time, threadTeam):
    c_ThreadTeamEnd = conf.lib.OTF2_EvtWriter_ThreadTeamEnd
    c_ThreadTeamEnd.argtypes = [ ctypes.POINTER(EvtWriter), ctypes.POINTER(AttributeList), TimeStamp, CommRef ]
    c_ThreadTeamEnd.restype = ErrorCode
    c_ThreadTeamEnd.errcheck = HandleErrorCode
    c_ThreadTeamEnd(writer, attributeList, time, threadTeam)

def EvtWriter_ThreadAcquireLock(writer, attributeList, time, model, lockID, acquisitionOrder):
    c_ThreadAcquireLock = conf.lib.OTF2_EvtWriter_ThreadAcquireLock
    c_ThreadAcquireLock.argtypes = [ ctypes.POINTER(EvtWriter), ctypes.POINTER(AttributeList), TimeStamp, Paradigm, ctypes.c_uint32, ctypes.c_uint32 ]
    c_ThreadAcquireLock.restype = ErrorCode
    c_ThreadAcquireLock.errcheck = HandleErrorCode
    c_ThreadAcquireLock(writer, attributeList, time, model, lockID, acquisitionOrder)

def EvtWriter_ThreadReleaseLock(writer, attributeList, time, model, lockID, acquisitionOrder):
    c_ThreadReleaseLock = conf.lib.OTF2_EvtWriter_ThreadReleaseLock
    c_ThreadReleaseLock.argtypes = [ ctypes.POINTER(EvtWriter), ctypes.POINTER(AttributeList), TimeStamp, Paradigm, ctypes.c_uint32, ctypes.c_uint32 ]
    c_ThreadReleaseLock.restype = ErrorCode
    c_ThreadReleaseLock.errcheck = HandleErrorCode
    c_ThreadReleaseLock(writer, attributeList, time, model, lockID, acquisitionOrder)

def EvtWriter_ThreadTaskCreate(writer, attributeList, time, threadTeam, creatingThread, generationNumber):
    c_ThreadTaskCreate = conf.lib.OTF2_EvtWriter_ThreadTaskCreate
    c_ThreadTaskCreate.argtypes = [ ctypes.POINTER(EvtWriter), ctypes.POINTER(AttributeList), TimeStamp, CommRef, ctypes.c_uint32, ctypes.c_uint32 ]
    c_ThreadTaskCreate.restype = ErrorCode
    c_ThreadTaskCreate.errcheck = HandleErrorCode
    c_ThreadTaskCreate(writer, attributeList, time, threadTeam, creatingThread, generationNumber)

def EvtWriter_ThreadTaskSwitch(writer, attributeList, time, threadTeam, creatingThread, generationNumber):
    c_ThreadTaskSwitch = conf.lib.OTF2_EvtWriter_ThreadTaskSwitch
    c_ThreadTaskSwitch.argtypes = [ ctypes.POINTER(EvtWriter), ctypes.POINTER(AttributeList), TimeStamp, CommRef, ctypes.c_uint32, ctypes.c_uint32 ]
    c_ThreadTaskSwitch.restype = ErrorCode
    c_ThreadTaskSwitch.errcheck = HandleErrorCode
    c_ThreadTaskSwitch(writer, attributeList, time, threadTeam, creatingThread, generationNumber)

def EvtWriter_ThreadTaskComplete(writer, attributeList, time, threadTeam, creatingThread, generationNumber):
    c_ThreadTaskComplete = conf.lib.OTF2_EvtWriter_ThreadTaskComplete
    c_ThreadTaskComplete.argtypes = [ ctypes.POINTER(EvtWriter), ctypes.POINTER(AttributeList), TimeStamp, CommRef, ctypes.c_uint32, ctypes.c_uint32 ]
    c_ThreadTaskComplete.restype = ErrorCode
    c_ThreadTaskComplete.errcheck = HandleErrorCode
    c_ThreadTaskComplete(writer, attributeList, time, threadTeam, creatingThread, generationNumber)

def EvtWriter_ThreadCreate(writer, attributeList, time, threadContingent, sequenceCount):
    c_ThreadCreate = conf.lib.OTF2_EvtWriter_ThreadCreate
    c_ThreadCreate.argtypes = [ ctypes.POINTER(EvtWriter), ctypes.POINTER(AttributeList), TimeStamp, CommRef, ctypes.c_uint64 ]
    c_ThreadCreate.restype = ErrorCode
    c_ThreadCreate.errcheck = HandleErrorCode
    c_ThreadCreate(writer, attributeList, time, threadContingent, sequenceCount)

def EvtWriter_ThreadBegin(writer, attributeList, time, threadContingent, sequenceCount):
    c_ThreadBegin = conf.lib.OTF2_EvtWriter_ThreadBegin
    c_ThreadBegin.argtypes = [ ctypes.POINTER(EvtWriter), ctypes.POINTER(AttributeList), TimeStamp, CommRef, ctypes.c_uint64 ]
    c_ThreadBegin.restype = ErrorCode
    c_ThreadBegin.errcheck = HandleErrorCode
    c_ThreadBegin(writer, attributeList, time, threadContingent, sequenceCount)

def EvtWriter_ThreadWait(writer, attributeList, time, threadContingent, sequenceCount):
    c_ThreadWait = conf.lib.OTF2_EvtWriter_ThreadWait
    c_ThreadWait.argtypes = [ ctypes.POINTER(EvtWriter), ctypes.POINTER(AttributeList), TimeStamp, CommRef, ctypes.c_uint64 ]
    c_ThreadWait.restype = ErrorCode
    c_ThreadWait.errcheck = HandleErrorCode
    c_ThreadWait(writer, attributeList, time, threadContingent, sequenceCount)

def EvtWriter_ThreadEnd(writer, attributeList, time, threadContingent, sequenceCount):
    c_ThreadEnd = conf.lib.OTF2_EvtWriter_ThreadEnd
    c_ThreadEnd.argtypes = [ ctypes.POINTER(EvtWriter), ctypes.POINTER(AttributeList), TimeStamp, CommRef, ctypes.c_uint64 ]
    c_ThreadEnd.restype = ErrorCode
    c_ThreadEnd.errcheck = HandleErrorCode
    c_ThreadEnd(writer, attributeList, time, threadContingent, sequenceCount)

def EvtWriter_CallingContextEnter(writer, attributeList, time, callingContext, unwindDistance):
    c_CallingContextEnter = conf.lib.OTF2_EvtWriter_CallingContextEnter
    c_CallingContextEnter.argtypes = [ ctypes.POINTER(EvtWriter), ctypes.POINTER(AttributeList), TimeStamp, CallingContextRef, ctypes.c_uint32 ]
    c_CallingContextEnter.restype = ErrorCode
    c_CallingContextEnter.errcheck = HandleErrorCode
    c_CallingContextEnter(writer, attributeList, time, callingContext, unwindDistance)

def EvtWriter_CallingContextLeave(writer, attributeList, time, callingContext):
    c_CallingContextLeave = conf.lib.OTF2_EvtWriter_CallingContextLeave
    c_CallingContextLeave.argtypes = [ ctypes.POINTER(EvtWriter), ctypes.POINTER(AttributeList), TimeStamp, CallingContextRef ]
    c_CallingContextLeave.restype = ErrorCode
    c_CallingContextLeave.errcheck = HandleErrorCode
    c_CallingContextLeave(writer, attributeList, time, callingContext)

def EvtWriter_CallingContextSample(writer, attributeList, time, callingContext, unwindDistance, interruptGenerator):
    c_CallingContextSample = conf.lib.OTF2_EvtWriter_CallingContextSample
    c_CallingContextSample.argtypes = [ ctypes.POINTER(EvtWriter), ctypes.POINTER(AttributeList), TimeStamp, CallingContextRef, ctypes.c_uint32, InterruptGeneratorRef ]
    c_CallingContextSample.restype = ErrorCode
    c_CallingContextSample.errcheck = HandleErrorCode
    c_CallingContextSample(writer, attributeList, time, callingContext, unwindDistance, interruptGenerator)

def EvtWriter_IoCreateHandle(writer, attributeList, time, handle, mode, creationFlags, statusFlags):
    c_IoCreateHandle = conf.lib.OTF2_EvtWriter_IoCreateHandle
    c_IoCreateHandle.argtypes = [ ctypes.POINTER(EvtWriter), ctypes.POINTER(AttributeList), TimeStamp, IoHandleRef, IoAccessMode, IoCreationFlag, IoStatusFlag ]
    c_IoCreateHandle.restype = ErrorCode
    c_IoCreateHandle.errcheck = HandleErrorCode
    c_IoCreateHandle(writer, attributeList, time, handle, mode, creationFlags, statusFlags)

def EvtWriter_IoDestroyHandle(writer, attributeList, time, handle):
    c_IoDestroyHandle = conf.lib.OTF2_EvtWriter_IoDestroyHandle
    c_IoDestroyHandle.argtypes = [ ctypes.POINTER(EvtWriter), ctypes.POINTER(AttributeList), TimeStamp, IoHandleRef ]
    c_IoDestroyHandle.restype = ErrorCode
    c_IoDestroyHandle.errcheck = HandleErrorCode
    c_IoDestroyHandle(writer, attributeList, time, handle)

def EvtWriter_IoDuplicateHandle(writer, attributeList, time, oldHandle, newHandle, statusFlags):
    c_IoDuplicateHandle = conf.lib.OTF2_EvtWriter_IoDuplicateHandle
    c_IoDuplicateHandle.argtypes = [ ctypes.POINTER(EvtWriter), ctypes.POINTER(AttributeList), TimeStamp, IoHandleRef, IoHandleRef, IoStatusFlag ]
    c_IoDuplicateHandle.restype = ErrorCode
    c_IoDuplicateHandle.errcheck = HandleErrorCode
    c_IoDuplicateHandle(writer, attributeList, time, oldHandle, newHandle, statusFlags)

def EvtWriter_IoSeek(writer, attributeList, time, handle, offsetRequest, whence, offsetResult):
    c_IoSeek = conf.lib.OTF2_EvtWriter_IoSeek
    c_IoSeek.argtypes = [ ctypes.POINTER(EvtWriter), ctypes.POINTER(AttributeList), TimeStamp, IoHandleRef, ctypes.c_int64, IoSeekOption, ctypes.c_uint64 ]
    c_IoSeek.restype = ErrorCode
    c_IoSeek.errcheck = HandleErrorCode
    c_IoSeek(writer, attributeList, time, handle, offsetRequest, whence, offsetResult)

def EvtWriter_IoChangeStatusFlags(writer, attributeList, time, handle, statusFlags):
    c_IoChangeStatusFlags = conf.lib.OTF2_EvtWriter_IoChangeStatusFlags
    c_IoChangeStatusFlags.argtypes = [ ctypes.POINTER(EvtWriter), ctypes.POINTER(AttributeList), TimeStamp, IoHandleRef, IoStatusFlag ]
    c_IoChangeStatusFlags.restype = ErrorCode
    c_IoChangeStatusFlags.errcheck = HandleErrorCode
    c_IoChangeStatusFlags(writer, attributeList, time, handle, statusFlags)

def EvtWriter_IoDeleteFile(writer, attributeList, time, ioParadigm, file):
    c_IoDeleteFile = conf.lib.OTF2_EvtWriter_IoDeleteFile
    c_IoDeleteFile.argtypes = [ ctypes.POINTER(EvtWriter), ctypes.POINTER(AttributeList), TimeStamp, IoParadigmRef, IoFileRef ]
    c_IoDeleteFile.restype = ErrorCode
    c_IoDeleteFile.errcheck = HandleErrorCode
    c_IoDeleteFile(writer, attributeList, time, ioParadigm, file)

def EvtWriter_IoOperationBegin(writer, attributeList, time, handle, mode, operationFlags, bytesRequest, matchingId):
    c_IoOperationBegin = conf.lib.OTF2_EvtWriter_IoOperationBegin
    c_IoOperationBegin.argtypes = [ ctypes.POINTER(EvtWriter), ctypes.POINTER(AttributeList), TimeStamp, IoHandleRef, IoOperationMode, IoOperationFlag, ctypes.c_uint64, ctypes.c_uint64 ]
    c_IoOperationBegin.restype = ErrorCode
    c_IoOperationBegin.errcheck = HandleErrorCode
    c_IoOperationBegin(writer, attributeList, time, handle, mode, operationFlags, bytesRequest, matchingId)

def EvtWriter_IoOperationTest(writer, attributeList, time, handle, matchingId):
    c_IoOperationTest = conf.lib.OTF2_EvtWriter_IoOperationTest
    c_IoOperationTest.argtypes = [ ctypes.POINTER(EvtWriter), ctypes.POINTER(AttributeList), TimeStamp, IoHandleRef, ctypes.c_uint64 ]
    c_IoOperationTest.restype = ErrorCode
    c_IoOperationTest.errcheck = HandleErrorCode
    c_IoOperationTest(writer, attributeList, time, handle, matchingId)

def EvtWriter_IoOperationIssued(writer, attributeList, time, handle, matchingId):
    c_IoOperationIssued = conf.lib.OTF2_EvtWriter_IoOperationIssued
    c_IoOperationIssued.argtypes = [ ctypes.POINTER(EvtWriter), ctypes.POINTER(AttributeList), TimeStamp, IoHandleRef, ctypes.c_uint64 ]
    c_IoOperationIssued.restype = ErrorCode
    c_IoOperationIssued.errcheck = HandleErrorCode
    c_IoOperationIssued(writer, attributeList, time, handle, matchingId)

def EvtWriter_IoOperationComplete(writer, attributeList, time, handle, bytesResult, matchingId):
    c_IoOperationComplete = conf.lib.OTF2_EvtWriter_IoOperationComplete
    c_IoOperationComplete.argtypes = [ ctypes.POINTER(EvtWriter), ctypes.POINTER(AttributeList), TimeStamp, IoHandleRef, ctypes.c_uint64, ctypes.c_uint64 ]
    c_IoOperationComplete.restype = ErrorCode
    c_IoOperationComplete.errcheck = HandleErrorCode
    c_IoOperationComplete(writer, attributeList, time, handle, bytesResult, matchingId)

def EvtWriter_IoOperationCancelled(writer, attributeList, time, handle, matchingId):
    c_IoOperationCancelled = conf.lib.OTF2_EvtWriter_IoOperationCancelled
    c_IoOperationCancelled.argtypes = [ ctypes.POINTER(EvtWriter), ctypes.POINTER(AttributeList), TimeStamp, IoHandleRef, ctypes.c_uint64 ]
    c_IoOperationCancelled.restype = ErrorCode
    c_IoOperationCancelled.errcheck = HandleErrorCode
    c_IoOperationCancelled(writer, attributeList, time, handle, matchingId)

def EvtWriter_IoAcquireLock(writer, attributeList, time, handle, lockType):
    c_IoAcquireLock = conf.lib.OTF2_EvtWriter_IoAcquireLock
    c_IoAcquireLock.argtypes = [ ctypes.POINTER(EvtWriter), ctypes.POINTER(AttributeList), TimeStamp, IoHandleRef, LockType ]
    c_IoAcquireLock.restype = ErrorCode
    c_IoAcquireLock.errcheck = HandleErrorCode
    c_IoAcquireLock(writer, attributeList, time, handle, lockType)

def EvtWriter_IoReleaseLock(writer, attributeList, time, handle, lockType):
    c_IoReleaseLock = conf.lib.OTF2_EvtWriter_IoReleaseLock
    c_IoReleaseLock.argtypes = [ ctypes.POINTER(EvtWriter), ctypes.POINTER(AttributeList), TimeStamp, IoHandleRef, LockType ]
    c_IoReleaseLock.restype = ErrorCode
    c_IoReleaseLock.errcheck = HandleErrorCode
    c_IoReleaseLock(writer, attributeList, time, handle, lockType)

def EvtWriter_IoTryLock(writer, attributeList, time, handle, lockType):
    c_IoTryLock = conf.lib.OTF2_EvtWriter_IoTryLock
    c_IoTryLock.argtypes = [ ctypes.POINTER(EvtWriter), ctypes.POINTER(AttributeList), TimeStamp, IoHandleRef, LockType ]
    c_IoTryLock.restype = ErrorCode
    c_IoTryLock.errcheck = HandleErrorCode
    c_IoTryLock(writer, attributeList, time, handle, lockType)

def EvtWriter_ProgramBegin(writer, attributeList, time, programName, programArguments):
    numberOfArguments = len(programArguments)
    StringRefArrayType = StringRef * numberOfArguments
    argument_list = StringRefArrayType()
    argument_list[:] = programArguments

    c_ProgramBegin = conf.lib.OTF2_EvtWriter_ProgramBegin
    c_ProgramBegin.argtypes = [ ctypes.POINTER(EvtWriter), ctypes.POINTER(AttributeList), TimeStamp, StringRef, ctypes.c_uint32, StringRefArrayType ]
    c_ProgramBegin.restype = ErrorCode
    c_ProgramBegin.errcheck = HandleErrorCode
    c_ProgramBegin(writer, attributeList, time , programName, numberOfArguments, argument_list)

def EvtWriter_ProgramEnd(writer, attributeList, time, exitStatus):
    c_ProgramEnd = conf.lib.OTF2_EvtWriter_ProgramEnd
    c_ProgramEnd.argtypes = [ ctypes.POINTER(EvtWriter), ctypes.POINTER(AttributeList), TimeStamp, ctypes.c_int64 ]
    c_ProgramEnd.restype = ErrorCode
    c_ProgramEnd.errcheck = HandleErrorCode
    c_ProgramEnd(writer, attributeList, time, exitStatus)

def EvtWriter_NonBlockingCollectiveRequest(writer, attributeList, time, requestID):
    c_NonBlockingCollectiveRequest = conf.lib.OTF2_EvtWriter_NonBlockingCollectiveRequest
    c_NonBlockingCollectiveRequest.argtypes = [ ctypes.POINTER(EvtWriter), ctypes.POINTER(AttributeList), TimeStamp, ctypes.c_uint64 ]
    c_NonBlockingCollectiveRequest.restype = ErrorCode
    c_NonBlockingCollectiveRequest.errcheck = HandleErrorCode
    c_NonBlockingCollectiveRequest(writer, attributeList, time, requestID)

def EvtWriter_NonBlockingCollectiveComplete(writer, attributeList, time, collectiveOp, communicator, root, sizeSent, sizeReceived, requestID):
    c_NonBlockingCollectiveComplete = conf.lib.OTF2_EvtWriter_NonBlockingCollectiveComplete
    c_NonBlockingCollectiveComplete.argtypes = [ ctypes.POINTER(EvtWriter), ctypes.POINTER(AttributeList), TimeStamp, CollectiveOp, CommRef, ctypes.c_uint32, ctypes.c_uint64, ctypes.c_uint64, ctypes.c_uint64 ]
    c_NonBlockingCollectiveComplete.restype = ErrorCode
    c_NonBlockingCollectiveComplete.errcheck = HandleErrorCode
    c_NonBlockingCollectiveComplete(writer, attributeList, time, collectiveOp, communicator, root, sizeSent, sizeReceived, requestID)

def EvtWriter_CommCreate(writer, attributeList, time, communicator):
    c_CommCreate = conf.lib.OTF2_EvtWriter_CommCreate
    c_CommCreate.argtypes = [ ctypes.POINTER(EvtWriter), ctypes.POINTER(AttributeList), TimeStamp, CommRef ]
    c_CommCreate.restype = ErrorCode
    c_CommCreate.errcheck = HandleErrorCode
    c_CommCreate(writer, attributeList, time, communicator)

def EvtWriter_CommDestroy(writer, attributeList, time, communicator):
    c_CommDestroy = conf.lib.OTF2_EvtWriter_CommDestroy
    c_CommDestroy.argtypes = [ ctypes.POINTER(EvtWriter), ctypes.POINTER(AttributeList), TimeStamp, CommRef ]
    c_CommDestroy.restype = ErrorCode
    c_CommDestroy.errcheck = HandleErrorCode
    c_CommDestroy(writer, attributeList, time, communicator)

__all__ = [
    'EvtWriter',
    'EvtWriter_GetLocationID',
    'EvtWriter_SetUserData',
    'EvtWriter_GetUserData',
    'EvtWriter_SetLocationID',
    'EvtWriter_GetNumberOfEvents',
    'EvtWriter_StoreRewindPoint',
    'EvtWriter_Rewind',
    'EvtWriter_ClearRewindPoint',
    'EvtWriter_BufferFlush',
    'EvtWriter_MeasurementOnOff',
    'EvtWriter_Enter',
    'EvtWriter_Leave',
    'EvtWriter_MpiSend',
    'EvtWriter_MpiIsend',
    'EvtWriter_MpiIsendComplete',
    'EvtWriter_MpiIrecvRequest',
    'EvtWriter_MpiRecv',
    'EvtWriter_MpiIrecv',
    'EvtWriter_MpiRequestTest',
    'EvtWriter_MpiRequestCancelled',
    'EvtWriter_MpiCollectiveBegin',
    'EvtWriter_MpiCollectiveEnd',
    'EvtWriter_OmpFork',
    'EvtWriter_OmpJoin',
    'EvtWriter_OmpAcquireLock',
    'EvtWriter_OmpReleaseLock',
    'EvtWriter_OmpTaskCreate',
    'EvtWriter_OmpTaskSwitch',
    'EvtWriter_OmpTaskComplete',
    'EvtWriter_Metric',
    'EvtWriter_ParameterString',
    'EvtWriter_ParameterInt',
    'EvtWriter_ParameterUnsignedInt',
    'EvtWriter_RmaWinCreate',
    'EvtWriter_RmaWinDestroy',
    'EvtWriter_RmaCollectiveBegin',
    'EvtWriter_RmaCollectiveEnd',
    'EvtWriter_RmaGroupSync',
    'EvtWriter_RmaRequestLock',
    'EvtWriter_RmaAcquireLock',
    'EvtWriter_RmaTryLock',
    'EvtWriter_RmaReleaseLock',
    'EvtWriter_RmaSync',
    'EvtWriter_RmaWaitChange',
    'EvtWriter_RmaPut',
    'EvtWriter_RmaGet',
    'EvtWriter_RmaAtomic',
    'EvtWriter_RmaOpCompleteBlocking',
    'EvtWriter_RmaOpCompleteNonBlocking',
    'EvtWriter_RmaOpTest',
    'EvtWriter_RmaOpCompleteRemote',
    'EvtWriter_ThreadFork',
    'EvtWriter_ThreadJoin',
    'EvtWriter_ThreadTeamBegin',
    'EvtWriter_ThreadTeamEnd',
    'EvtWriter_ThreadAcquireLock',
    'EvtWriter_ThreadReleaseLock',
    'EvtWriter_ThreadTaskCreate',
    'EvtWriter_ThreadTaskSwitch',
    'EvtWriter_ThreadTaskComplete',
    'EvtWriter_ThreadCreate',
    'EvtWriter_ThreadBegin',
    'EvtWriter_ThreadWait',
    'EvtWriter_ThreadEnd',
    'EvtWriter_CallingContextEnter',
    'EvtWriter_CallingContextLeave',
    'EvtWriter_CallingContextSample',
    'EvtWriter_IoCreateHandle',
    'EvtWriter_IoDestroyHandle',
    'EvtWriter_IoDuplicateHandle',
    'EvtWriter_IoSeek',
    'EvtWriter_IoChangeStatusFlags',
    'EvtWriter_IoDeleteFile',
    'EvtWriter_IoOperationBegin',
    'EvtWriter_IoOperationTest',
    'EvtWriter_IoOperationIssued',
    'EvtWriter_IoOperationComplete',
    'EvtWriter_IoOperationCancelled',
    'EvtWriter_IoAcquireLock',
    'EvtWriter_IoReleaseLock',
    'EvtWriter_IoTryLock',
    'EvtWriter_ProgramBegin',
    'EvtWriter_ProgramEnd',
    'EvtWriter_NonBlockingCollectiveRequest',
    'EvtWriter_NonBlockingCollectiveComplete',
    'EvtWriter_CommCreate',
    'EvtWriter_CommDestroy',
]




# Generated by OTF2 Template Engine

import _otf2


class _EnumWrapper(object):
    def __init__(self, prefix, enum_type=None):
        # This is a bit ugly, but IMHO at least less ugly than doing it in __getattr__
        self.__dict__['type'] = enum_type
        for (name, candidate) in _otf2.__dict__.items():
            if (enum_type is None or isinstance(candidate, enum_type)) and name.startswith(prefix):
                short_name = name[len(prefix):]
                self.__dict__[short_name] = candidate

    def __setattr__(self, name, value):
        raise AttributeError("Change of values is not allowed.")


# GeneralDefinitions
Undefined = _EnumWrapper("UNDEFINED_")

__all__ = ["Undefined", "FileMode", "FlushType", "Compression"]

FileMode = _otf2.FileMode
FlushType = _otf2.FlushType
Compression = _otf2.Compression

Boolean = _otf2.Boolean
__all__.append("Boolean")

FileType = _otf2.FileType
__all__.append("FileType")

FileSubstrate = _otf2.FileSubstrate
__all__.append("FileSubstrate")

MappingType = _otf2.MappingType
__all__.append("MappingType")

Type = _otf2.Type
__all__.append("Type")

Paradigm = _otf2.Paradigm
__all__.append("Paradigm")

ParadigmClass = _otf2.ParadigmClass
__all__.append("ParadigmClass")

ParadigmProperty = _otf2.ParadigmProperty
__all__.append("ParadigmProperty")

ThumbnailType = _otf2.ThumbnailType
__all__.append("ThumbnailType")

SystemTreeDomain = _otf2.SystemTreeDomain
__all__.append("SystemTreeDomain")

LocationGroupType = _otf2.LocationGroupType
__all__.append("LocationGroupType")

LocationType = _otf2.LocationType
__all__.append("LocationType")

RegionRole = _otf2.RegionRole
__all__.append("RegionRole")

RegionFlag = _otf2.RegionFlag
__all__.append("RegionFlag")

GroupType = _otf2.GroupType
__all__.append("GroupType")

GroupFlag = _otf2.GroupFlag
__all__.append("GroupFlag")

Base = _otf2.Base
__all__.append("Base")

MetricOccurrence = _otf2.MetricOccurrence
__all__.append("MetricOccurrence")

MetricType = _otf2.MetricType
__all__.append("MetricType")

MetricValueProperty = _otf2.MetricValueProperty
__all__.append("MetricValueProperty")

MetricTiming = _otf2.MetricTiming
__all__.append("MetricTiming")

MetricMode = _otf2.MetricMode
__all__.append("MetricMode")

MetricScope = _otf2.MetricScope
__all__.append("MetricScope")

RecorderKind = _otf2.RecorderKind
__all__.append("RecorderKind")

ParameterType = _otf2.ParameterType
__all__.append("ParameterType")

CartPeriodicity = _otf2.CartPeriodicity
__all__.append("CartPeriodicity")

InterruptGeneratorMode = _otf2.InterruptGeneratorMode
__all__.append("InterruptGeneratorMode")

MeasurementMode = _otf2.MeasurementMode
__all__.append("MeasurementMode")

CollectiveOp = _otf2.CollectiveOp
__all__.append("CollectiveOp")

RmaSyncType = _otf2.RmaSyncType
__all__.append("RmaSyncType")

RmaSyncLevel = _otf2.RmaSyncLevel
__all__.append("RmaSyncLevel")

LockType = _otf2.LockType
__all__.append("LockType")

RmaAtomicType = _otf2.RmaAtomicType
__all__.append("RmaAtomicType")

IoParadigmClass = _otf2.IoParadigmClass
__all__.append("IoParadigmClass")

IoParadigmFlag = _otf2.IoParadigmFlag
__all__.append("IoParadigmFlag")

IoParadigmProperty = _otf2.IoParadigmProperty
__all__.append("IoParadigmProperty")

IoHandleFlag = _otf2.IoHandleFlag
__all__.append("IoHandleFlag")

IoAccessMode = _otf2.IoAccessMode
__all__.append("IoAccessMode")

IoCreationFlag = _otf2.IoCreationFlag
__all__.append("IoCreationFlag")

IoStatusFlag = _otf2.IoStatusFlag
__all__.append("IoStatusFlag")

IoSeekOption = _otf2.IoSeekOption
__all__.append("IoSeekOption")

IoOperationMode = _otf2.IoOperationMode
__all__.append("IoOperationMode")

IoOperationFlag = _otf2.IoOperationFlag
__all__.append("IoOperationFlag")

CommFlag = _otf2.CommFlag
__all__.append("CommFlag")

RmaWinFlag = _otf2.RmaWinFlag
__all__.append("RmaWinFlag")

CollectiveRoot = _otf2.CollectiveRoot
__all__.append("CollectiveRoot")



import os
import os.path
import unittest
from shutil import rmtree
from tempfile import mkdtemp
import time

import otf2


TIMER_GRANULARITY = 1000000


def t():
    return int(round(time.time() * TIMER_GRANULARITY))


class TestOTF2Program(unittest.TestCase):
    def setUp(self):
        self.old_cwd = os.getcwd()
        self.tmp_dirname = mkdtemp(prefix=os.path.basename(os.path.abspath(__file__))[:-3] + '_tmp', dir=self.old_cwd)

        self.orig_trace = os.path.join(self.tmp_dirname, "orig")
        self.retrace = os.path.join(self.tmp_dirname, "retrc")

        os.mkdir(self.orig_trace)
        os.mkdir(self.retrace)

        os.chdir(self.tmp_dirname)

    def tearDown(self):
        os.chdir(self.old_cwd)
        if os.getenv('KEEP_TEST_OUTPUT', '') != '':
            print(self.tmp_dirname)
        else:
            rmtree(self.tmp_dirname)

    def generate_trace(self, archive_name):
        with otf2.writer.open(archive_name, timer_resolution=TIMER_GRANULARITY) as trace:
            system_tree_node = trace.definitions.system_tree_node("Root", parent=None)
            location_group = trace.definitions.location_group("Process",
                                                              system_tree_parent=system_tree_node)

            parameter = trace.definitions.parameter("Foo")

            writer = trace.event_writer("thread", group=location_group)

            writer.program_begin(t(), "foo", ["arg0", "arg1"])
            writer.program_end(t(), 0)

    def read_trace(self, archive_name):
        with otf2.reader.open(archive_name) as trace:
            # TODO check something
            pass

    def rewrite_trace(self, old_anchor_path, new_archive_path):
        with otf2.reader.open(old_anchor_path) as trace_reader:
            with otf2.writer.open(new_archive_path,
                                  definitions=trace_reader.definitions) as write_trace:
                for location, event in trace_reader.events:
                    writer = write_trace.event_writer_from_location(location)
                    writer(event)

    def test_rewrite(self):
        self.generate_trace(self.orig_trace)
        self.rewrite_trace(os.path.join(self.orig_trace, "traces.otf2"), self.retrace)
        self.read_trace(os.path.join(self.retrace, "traces.otf2"))


if __name__ == '__main__':
    unittest.main()
